package Locale::CLDR::LikelySubtags;
# This file auto generated from Data\common\supplemental\likelySubtags.xml
#	on Sun 30 Sep  9:00:51 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.33.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo::Role;

has 'likely_subtags' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default	=> sub { return {
		'aa'	=> 'aa_Latn_ET',
		'aai'	=> 'aai_Latn_ZZ',
		'aak'	=> 'aak_Latn_ZZ',
		'aau'	=> 'aau_Latn_ZZ',
		'ab'	=> 'ab_Cyrl_GE',
		'abi'	=> 'abi_Latn_ZZ',
		'abq'	=> 'abq_Cyrl_ZZ',
		'abr'	=> 'abr_Latn_GH',
		'abt'	=> 'abt_Latn_ZZ',
		'aby'	=> 'aby_Latn_ZZ',
		'acd'	=> 'acd_Latn_ZZ',
		'ace'	=> 'ace_Latn_ID',
		'ach'	=> 'ach_Latn_UG',
		'ada'	=> 'ada_Latn_GH',
		'ade'	=> 'ade_Latn_ZZ',
		'adj'	=> 'adj_Latn_ZZ',
		'ady'	=> 'ady_Cyrl_RU',
		'adz'	=> 'adz_Latn_ZZ',
		'ae'	=> 'ae_Avst_IR',
		'aeb'	=> 'aeb_Arab_TN',
		'aey'	=> 'aey_Latn_ZZ',
		'af'	=> 'af_Latn_ZA',
		'agc'	=> 'agc_Latn_ZZ',
		'agd'	=> 'agd_Latn_ZZ',
		'agg'	=> 'agg_Latn_ZZ',
		'agm'	=> 'agm_Latn_ZZ',
		'ago'	=> 'ago_Latn_ZZ',
		'agq'	=> 'agq_Latn_CM',
		'aha'	=> 'aha_Latn_ZZ',
		'ahl'	=> 'ahl_Latn_ZZ',
		'aho'	=> 'aho_Ahom_IN',
		'ajg'	=> 'ajg_Latn_ZZ',
		'ak'	=> 'ak_Latn_GH',
		'akk'	=> 'akk_Xsux_IQ',
		'ala'	=> 'ala_Latn_ZZ',
		'ali'	=> 'ali_Latn_ZZ',
		'aln'	=> 'aln_Latn_XK',
		'alt'	=> 'alt_Cyrl_RU',
		'am'	=> 'am_Ethi_ET',
		'amm'	=> 'amm_Latn_ZZ',
		'amn'	=> 'amn_Latn_ZZ',
		'amo'	=> 'amo_Latn_NG',
		'amp'	=> 'amp_Latn_ZZ',
		'anc'	=> 'anc_Latn_ZZ',
		'ank'	=> 'ank_Latn_ZZ',
		'ann'	=> 'ann_Latn_ZZ',
		'any'	=> 'any_Latn_ZZ',
		'aoj'	=> 'aoj_Latn_ZZ',
		'aom'	=> 'aom_Latn_ZZ',
		'aoz'	=> 'aoz_Latn_ID',
		'apc'	=> 'apc_Arab_ZZ',
		'apd'	=> 'apd_Arab_TG',
		'ape'	=> 'ape_Latn_ZZ',
		'apr'	=> 'apr_Latn_ZZ',
		'aps'	=> 'aps_Latn_ZZ',
		'apz'	=> 'apz_Latn_ZZ',
		'ar'	=> 'ar_Arab_EG',
		'arc'	=> 'arc_Armi_IR',
		'arc_Nbat'	=> 'arc_Nbat_JO',
		'arc_Palm'	=> 'arc_Palm_SY',
		'arh'	=> 'arh_Latn_ZZ',
		'arn'	=> 'arn_Latn_CL',
		'aro'	=> 'aro_Latn_BO',
		'arq'	=> 'arq_Arab_DZ',
		'ary'	=> 'ary_Arab_MA',
		'arz'	=> 'arz_Arab_EG',
		'as'	=> 'as_Beng_IN',
		'asa'	=> 'asa_Latn_TZ',
		'ase'	=> 'ase_Sgnw_US',
		'asg'	=> 'asg_Latn_ZZ',
		'aso'	=> 'aso_Latn_ZZ',
		'ast'	=> 'ast_Latn_ES',
		'ata'	=> 'ata_Latn_ZZ',
		'atg'	=> 'atg_Latn_ZZ',
		'atj'	=> 'atj_Latn_CA',
		'auy'	=> 'auy_Latn_ZZ',
		'av'	=> 'av_Cyrl_RU',
		'avl'	=> 'avl_Arab_ZZ',
		'avn'	=> 'avn_Latn_ZZ',
		'avt'	=> 'avt_Latn_ZZ',
		'avu'	=> 'avu_Latn_ZZ',
		'awa'	=> 'awa_Deva_IN',
		'awb'	=> 'awb_Latn_ZZ',
		'awo'	=> 'awo_Latn_ZZ',
		'awx'	=> 'awx_Latn_ZZ',
		'ay'	=> 'ay_Latn_BO',
		'ayb'	=> 'ayb_Latn_ZZ',
		'az'	=> 'az_Latn_AZ',
		'az_IQ'	=> 'az_Arab_IQ',
		'az_IR'	=> 'az_Arab_IR',
		'az_RU'	=> 'az_Cyrl_RU',
		'az_Arab'	=> 'az_Arab_IR',
		'ba'	=> 'ba_Cyrl_RU',
		'bal'	=> 'bal_Arab_PK',
		'ban'	=> 'ban_Latn_ID',
		'bap'	=> 'bap_Deva_NP',
		'bar'	=> 'bar_Latn_AT',
		'bas'	=> 'bas_Latn_CM',
		'bav'	=> 'bav_Latn_ZZ',
		'bax'	=> 'bax_Bamu_CM',
		'bba'	=> 'bba_Latn_ZZ',
		'bbb'	=> 'bbb_Latn_ZZ',
		'bbc'	=> 'bbc_Latn_ID',
		'bbd'	=> 'bbd_Latn_ZZ',
		'bbj'	=> 'bbj_Latn_CM',
		'bbp'	=> 'bbp_Latn_ZZ',
		'bbr'	=> 'bbr_Latn_ZZ',
		'bcf'	=> 'bcf_Latn_ZZ',
		'bch'	=> 'bch_Latn_ZZ',
		'bci'	=> 'bci_Latn_CI',
		'bcm'	=> 'bcm_Latn_ZZ',
		'bcn'	=> 'bcn_Latn_ZZ',
		'bco'	=> 'bco_Latn_ZZ',
		'bcq'	=> 'bcq_Ethi_ZZ',
		'bcu'	=> 'bcu_Latn_ZZ',
		'bdd'	=> 'bdd_Latn_ZZ',
		'be'	=> 'be_Cyrl_BY',
		'bef'	=> 'bef_Latn_ZZ',
		'beh'	=> 'beh_Latn_ZZ',
		'bej'	=> 'bej_Arab_SD',
		'bem'	=> 'bem_Latn_ZM',
		'bet'	=> 'bet_Latn_ZZ',
		'bew'	=> 'bew_Latn_ID',
		'bex'	=> 'bex_Latn_ZZ',
		'bez'	=> 'bez_Latn_TZ',
		'bfd'	=> 'bfd_Latn_CM',
		'bfq'	=> 'bfq_Taml_IN',
		'bft'	=> 'bft_Arab_PK',
		'bfy'	=> 'bfy_Deva_IN',
		'bg'	=> 'bg_Cyrl_BG',
		'bgc'	=> 'bgc_Deva_IN',
		'bgn'	=> 'bgn_Arab_PK',
		'bgx'	=> 'bgx_Grek_TR',
		'bhb'	=> 'bhb_Deva_IN',
		'bhg'	=> 'bhg_Latn_ZZ',
		'bhi'	=> 'bhi_Deva_IN',
		'bhk'	=> 'bhk_Latn_PH',
		'bhl'	=> 'bhl_Latn_ZZ',
		'bho'	=> 'bho_Deva_IN',
		'bhy'	=> 'bhy_Latn_ZZ',
		'bi'	=> 'bi_Latn_VU',
		'bib'	=> 'bib_Latn_ZZ',
		'big'	=> 'big_Latn_ZZ',
		'bik'	=> 'bik_Latn_PH',
		'bim'	=> 'bim_Latn_ZZ',
		'bin'	=> 'bin_Latn_NG',
		'bio'	=> 'bio_Latn_ZZ',
		'biq'	=> 'biq_Latn_ZZ',
		'bjh'	=> 'bjh_Latn_ZZ',
		'bji'	=> 'bji_Ethi_ZZ',
		'bjj'	=> 'bjj_Deva_IN',
		'bjn'	=> 'bjn_Latn_ID',
		'bjo'	=> 'bjo_Latn_ZZ',
		'bjr'	=> 'bjr_Latn_ZZ',
		'bjt'	=> 'bjt_Latn_SN',
		'bjz'	=> 'bjz_Latn_ZZ',
		'bkc'	=> 'bkc_Latn_ZZ',
		'bkm'	=> 'bkm_Latn_CM',
		'bkq'	=> 'bkq_Latn_ZZ',
		'bku'	=> 'bku_Latn_PH',
		'bkv'	=> 'bkv_Latn_ZZ',
		'blt'	=> 'blt_Tavt_VN',
		'bm'	=> 'bm_Latn_ML',
		'bmh'	=> 'bmh_Latn_ZZ',
		'bmk'	=> 'bmk_Latn_ZZ',
		'bmq'	=> 'bmq_Latn_ML',
		'bmu'	=> 'bmu_Latn_ZZ',
		'bn'	=> 'bn_Beng_BD',
		'bng'	=> 'bng_Latn_ZZ',
		'bnm'	=> 'bnm_Latn_ZZ',
		'bnp'	=> 'bnp_Latn_ZZ',
		'bo'	=> 'bo_Tibt_CN',
		'boj'	=> 'boj_Latn_ZZ',
		'bom'	=> 'bom_Latn_ZZ',
		'bon'	=> 'bon_Latn_ZZ',
		'bpy'	=> 'bpy_Beng_IN',
		'bqc'	=> 'bqc_Latn_ZZ',
		'bqi'	=> 'bqi_Arab_IR',
		'bqp'	=> 'bqp_Latn_ZZ',
		'bqv'	=> 'bqv_Latn_CI',
		'br'	=> 'br_Latn_FR',
		'bra'	=> 'bra_Deva_IN',
		'brh'	=> 'brh_Arab_PK',
		'brx'	=> 'brx_Deva_IN',
		'brz'	=> 'brz_Latn_ZZ',
		'bs'	=> 'bs_Latn_BA',
		'bsj'	=> 'bsj_Latn_ZZ',
		'bsq'	=> 'bsq_Bass_LR',
		'bss'	=> 'bss_Latn_CM',
		'bst'	=> 'bst_Ethi_ZZ',
		'bto'	=> 'bto_Latn_PH',
		'btt'	=> 'btt_Latn_ZZ',
		'btv'	=> 'btv_Deva_PK',
		'bua'	=> 'bua_Cyrl_RU',
		'buc'	=> 'buc_Latn_YT',
		'bud'	=> 'bud_Latn_ZZ',
		'bug'	=> 'bug_Latn_ID',
		'buk'	=> 'buk_Latn_ZZ',
		'bum'	=> 'bum_Latn_CM',
		'buo'	=> 'buo_Latn_ZZ',
		'bus'	=> 'bus_Latn_ZZ',
		'buu'	=> 'buu_Latn_ZZ',
		'bvb'	=> 'bvb_Latn_GQ',
		'bwd'	=> 'bwd_Latn_ZZ',
		'bwr'	=> 'bwr_Latn_ZZ',
		'bxh'	=> 'bxh_Latn_ZZ',
		'bye'	=> 'bye_Latn_ZZ',
		'byn'	=> 'byn_Ethi_ER',
		'byr'	=> 'byr_Latn_ZZ',
		'bys'	=> 'bys_Latn_ZZ',
		'byv'	=> 'byv_Latn_CM',
		'byx'	=> 'byx_Latn_ZZ',
		'bza'	=> 'bza_Latn_ZZ',
		'bze'	=> 'bze_Latn_ML',
		'bzf'	=> 'bzf_Latn_ZZ',
		'bzh'	=> 'bzh_Latn_ZZ',
		'bzw'	=> 'bzw_Latn_ZZ',
		'ca'	=> 'ca_Latn_ES',
		'can'	=> 'can_Latn_ZZ',
		'cbj'	=> 'cbj_Latn_ZZ',
		'cch'	=> 'cch_Latn_NG',
		'ccp'	=> 'ccp_Cakm_BD',
		'ce'	=> 'ce_Cyrl_RU',
		'ceb'	=> 'ceb_Latn_PH',
		'cfa'	=> 'cfa_Latn_ZZ',
		'cgg'	=> 'cgg_Latn_UG',
		'ch'	=> 'ch_Latn_GU',
		'chk'	=> 'chk_Latn_FM',
		'chm'	=> 'chm_Cyrl_RU',
		'cho'	=> 'cho_Latn_US',
		'chp'	=> 'chp_Latn_CA',
		'chr'	=> 'chr_Cher_US',
		'cja'	=> 'cja_Arab_KH',
		'cjm'	=> 'cjm_Cham_VN',
		'cjv'	=> 'cjv_Latn_ZZ',
		'ckb'	=> 'ckb_Arab_IQ',
		'ckl'	=> 'ckl_Latn_ZZ',
		'cko'	=> 'cko_Latn_ZZ',
		'cky'	=> 'cky_Latn_ZZ',
		'cla'	=> 'cla_Latn_ZZ',
		'cme'	=> 'cme_Latn_ZZ',
		'cmg'	=> 'cmg_Soyo_MN',
		'co'	=> 'co_Latn_FR',
		'cop'	=> 'cop_Copt_EG',
		'cps'	=> 'cps_Latn_PH',
		'cr'	=> 'cr_Cans_CA',
		'crh'	=> 'crh_Cyrl_UA',
		'crj'	=> 'crj_Cans_CA',
		'crk'	=> 'crk_Cans_CA',
		'crl'	=> 'crl_Cans_CA',
		'crm'	=> 'crm_Cans_CA',
		'crs'	=> 'crs_Latn_SC',
		'cs'	=> 'cs_Latn_CZ',
		'csb'	=> 'csb_Latn_PL',
		'csw'	=> 'csw_Cans_CA',
		'ctd'	=> 'ctd_Pauc_MM',
		'cu'	=> 'cu_Cyrl_RU',
		'cu_Glag'	=> 'cu_Glag_BG',
		'cv'	=> 'cv_Cyrl_RU',
		'cy'	=> 'cy_Latn_GB',
		'da'	=> 'da_Latn_DK',
		'dad'	=> 'dad_Latn_ZZ',
		'daf'	=> 'daf_Latn_ZZ',
		'dag'	=> 'dag_Latn_ZZ',
		'dah'	=> 'dah_Latn_ZZ',
		'dak'	=> 'dak_Latn_US',
		'dar'	=> 'dar_Cyrl_RU',
		'dav'	=> 'dav_Latn_KE',
		'dbd'	=> 'dbd_Latn_ZZ',
		'dbq'	=> 'dbq_Latn_ZZ',
		'dcc'	=> 'dcc_Arab_IN',
		'ddn'	=> 'ddn_Latn_ZZ',
		'de'	=> 'de_Latn_DE',
		'ded'	=> 'ded_Latn_ZZ',
		'den'	=> 'den_Latn_CA',
		'dga'	=> 'dga_Latn_ZZ',
		'dgh'	=> 'dgh_Latn_ZZ',
		'dgi'	=> 'dgi_Latn_ZZ',
		'dgl'	=> 'dgl_Arab_ZZ',
		'dgr'	=> 'dgr_Latn_CA',
		'dgz'	=> 'dgz_Latn_ZZ',
		'dia'	=> 'dia_Latn_ZZ',
		'dje'	=> 'dje_Latn_NE',
		'dnj'	=> 'dnj_Latn_CI',
		'dob'	=> 'dob_Latn_ZZ',
		'doi'	=> 'doi_Arab_IN',
		'dop'	=> 'dop_Latn_ZZ',
		'dow'	=> 'dow_Latn_ZZ',
		'dri'	=> 'dri_Latn_ZZ',
		'drs'	=> 'drs_Ethi_ZZ',
		'dsb'	=> 'dsb_Latn_DE',
		'dtm'	=> 'dtm_Latn_ML',
		'dtp'	=> 'dtp_Latn_MY',
		'dts'	=> 'dts_Latn_ZZ',
		'dty'	=> 'dty_Deva_NP',
		'dua'	=> 'dua_Latn_CM',
		'duc'	=> 'duc_Latn_ZZ',
		'dud'	=> 'dud_Latn_ZZ',
		'dug'	=> 'dug_Latn_ZZ',
		'dv'	=> 'dv_Thaa_MV',
		'dva'	=> 'dva_Latn_ZZ',
		'dww'	=> 'dww_Latn_ZZ',
		'dyo'	=> 'dyo_Latn_SN',
		'dyu'	=> 'dyu_Latn_BF',
		'dz'	=> 'dz_Tibt_BT',
		'dzg'	=> 'dzg_Latn_ZZ',
		'ebu'	=> 'ebu_Latn_KE',
		'ee'	=> 'ee_Latn_GH',
		'efi'	=> 'efi_Latn_NG',
		'egl'	=> 'egl_Latn_IT',
		'egy'	=> 'egy_Egyp_EG',
		'eka'	=> 'eka_Latn_ZZ',
		'eky'	=> 'eky_Kali_MM',
		'el'	=> 'el_Grek_GR',
		'ema'	=> 'ema_Latn_ZZ',
		'emi'	=> 'emi_Latn_ZZ',
		'en'	=> 'en_Latn_US',
		'en_Shaw'	=> 'en_Shaw_GB',
		'enn'	=> 'enn_Latn_ZZ',
		'enq'	=> 'enq_Latn_ZZ',
		'eo'	=> 'eo_Latn_001',
		'eri'	=> 'eri_Latn_ZZ',
		'es'	=> 'es_Latn_ES',
		'esg'	=> 'esg_Gonm_IN',
		'esu'	=> 'esu_Latn_US',
		'et'	=> 'et_Latn_EE',
		'etr'	=> 'etr_Latn_ZZ',
		'ett'	=> 'ett_Ital_IT',
		'etu'	=> 'etu_Latn_ZZ',
		'etx'	=> 'etx_Latn_ZZ',
		'eu'	=> 'eu_Latn_ES',
		'ewo'	=> 'ewo_Latn_CM',
		'ext'	=> 'ext_Latn_ES',
		'fa'	=> 'fa_Arab_IR',
		'faa'	=> 'faa_Latn_ZZ',
		'fab'	=> 'fab_Latn_ZZ',
		'fag'	=> 'fag_Latn_ZZ',
		'fai'	=> 'fai_Latn_ZZ',
		'fan'	=> 'fan_Latn_GQ',
		'ff'	=> 'ff_Latn_SN',
		'ff_Adlm'	=> 'ff_Adlm_GN',
		'ffi'	=> 'ffi_Latn_ZZ',
		'ffm'	=> 'ffm_Latn_ML',
		'fi'	=> 'fi_Latn_FI',
		'fia'	=> 'fia_Arab_SD',
		'fil'	=> 'fil_Latn_PH',
		'fit'	=> 'fit_Latn_SE',
		'fj'	=> 'fj_Latn_FJ',
		'flr'	=> 'flr_Latn_ZZ',
		'fmp'	=> 'fmp_Latn_ZZ',
		'fo'	=> 'fo_Latn_FO',
		'fod'	=> 'fod_Latn_ZZ',
		'fon'	=> 'fon_Latn_BJ',
		'for'	=> 'for_Latn_ZZ',
		'fpe'	=> 'fpe_Latn_ZZ',
		'fqs'	=> 'fqs_Latn_ZZ',
		'fr'	=> 'fr_Latn_FR',
		'frc'	=> 'frc_Latn_US',
		'frp'	=> 'frp_Latn_FR',
		'frr'	=> 'frr_Latn_DE',
		'frs'	=> 'frs_Latn_DE',
		'fub'	=> 'fub_Arab_CM',
		'fud'	=> 'fud_Latn_WF',
		'fue'	=> 'fue_Latn_ZZ',
		'fuf'	=> 'fuf_Latn_GN',
		'fuh'	=> 'fuh_Latn_ZZ',
		'fuq'	=> 'fuq_Latn_NE',
		'fur'	=> 'fur_Latn_IT',
		'fuv'	=> 'fuv_Latn_NG',
		'fuy'	=> 'fuy_Latn_ZZ',
		'fvr'	=> 'fvr_Latn_SD',
		'fy'	=> 'fy_Latn_NL',
		'ga'	=> 'ga_Latn_IE',
		'gaa'	=> 'gaa_Latn_GH',
		'gaf'	=> 'gaf_Latn_ZZ',
		'gag'	=> 'gag_Latn_MD',
		'gah'	=> 'gah_Latn_ZZ',
		'gaj'	=> 'gaj_Latn_ZZ',
		'gam'	=> 'gam_Latn_ZZ',
		'gan'	=> 'gan_Hans_CN',
		'gaw'	=> 'gaw_Latn_ZZ',
		'gay'	=> 'gay_Latn_ID',
		'gba'	=> 'gba_Latn_ZZ',
		'gbf'	=> 'gbf_Latn_ZZ',
		'gbm'	=> 'gbm_Deva_IN',
		'gby'	=> 'gby_Latn_ZZ',
		'gbz'	=> 'gbz_Arab_IR',
		'gcr'	=> 'gcr_Latn_GF',
		'gd'	=> 'gd_Latn_GB',
		'gde'	=> 'gde_Latn_ZZ',
		'gdn'	=> 'gdn_Latn_ZZ',
		'gdr'	=> 'gdr_Latn_ZZ',
		'geb'	=> 'geb_Latn_ZZ',
		'gej'	=> 'gej_Latn_ZZ',
		'gel'	=> 'gel_Latn_ZZ',
		'gez'	=> 'gez_Ethi_ET',
		'gfk'	=> 'gfk_Latn_ZZ',
		'ggn'	=> 'ggn_Deva_NP',
		'ghs'	=> 'ghs_Latn_ZZ',
		'gil'	=> 'gil_Latn_KI',
		'gim'	=> 'gim_Latn_ZZ',
		'gjk'	=> 'gjk_Arab_PK',
		'gjn'	=> 'gjn_Latn_ZZ',
		'gju'	=> 'gju_Arab_PK',
		'gkn'	=> 'gkn_Latn_ZZ',
		'gkp'	=> 'gkp_Latn_ZZ',
		'gl'	=> 'gl_Latn_ES',
		'glk'	=> 'glk_Arab_IR',
		'gmm'	=> 'gmm_Latn_ZZ',
		'gmv'	=> 'gmv_Ethi_ZZ',
		'gn'	=> 'gn_Latn_PY',
		'gnd'	=> 'gnd_Latn_ZZ',
		'gng'	=> 'gng_Latn_ZZ',
		'god'	=> 'god_Latn_ZZ',
		'gof'	=> 'gof_Ethi_ZZ',
		'goi'	=> 'goi_Latn_ZZ',
		'gom'	=> 'gom_Deva_IN',
		'gon'	=> 'gon_Telu_IN',
		'gor'	=> 'gor_Latn_ID',
		'gos'	=> 'gos_Latn_NL',
		'got'	=> 'got_Goth_UA',
		'grb'	=> 'grb_Latn_ZZ',
		'grc'	=> 'grc_Cprt_CY',
		'grc_Linb'	=> 'grc_Linb_GR',
		'grt'	=> 'grt_Beng_IN',
		'grw'	=> 'grw_Latn_ZZ',
		'gsw'	=> 'gsw_Latn_CH',
		'gu'	=> 'gu_Gujr_IN',
		'gub'	=> 'gub_Latn_BR',
		'guc'	=> 'guc_Latn_CO',
		'gud'	=> 'gud_Latn_ZZ',
		'gur'	=> 'gur_Latn_GH',
		'guw'	=> 'guw_Latn_ZZ',
		'gux'	=> 'gux_Latn_ZZ',
		'guz'	=> 'guz_Latn_KE',
		'gv'	=> 'gv_Latn_IM',
		'gvf'	=> 'gvf_Latn_ZZ',
		'gvr'	=> 'gvr_Deva_NP',
		'gvs'	=> 'gvs_Latn_ZZ',
		'gwc'	=> 'gwc_Arab_ZZ',
		'gwi'	=> 'gwi_Latn_CA',
		'gwt'	=> 'gwt_Arab_ZZ',
		'gyi'	=> 'gyi_Latn_ZZ',
		'ha'	=> 'ha_Latn_NG',
		'ha_CM'	=> 'ha_Arab_CM',
		'ha_SD'	=> 'ha_Arab_SD',
		'hag'	=> 'hag_Latn_ZZ',
		'hak'	=> 'hak_Hans_CN',
		'ham'	=> 'ham_Latn_ZZ',
		'haw'	=> 'haw_Latn_US',
		'haz'	=> 'haz_Arab_AF',
		'hbb'	=> 'hbb_Latn_ZZ',
		'hdy'	=> 'hdy_Ethi_ZZ',
		'he'	=> 'he_Hebr_IL',
		'hhy'	=> 'hhy_Latn_ZZ',
		'hi'	=> 'hi_Deva_IN',
		'hia'	=> 'hia_Latn_ZZ',
		'hif'	=> 'hif_Latn_FJ',
		'hig'	=> 'hig_Latn_ZZ',
		'hih'	=> 'hih_Latn_ZZ',
		'hil'	=> 'hil_Latn_PH',
		'hla'	=> 'hla_Latn_ZZ',
		'hlu'	=> 'hlu_Hluw_TR',
		'hmd'	=> 'hmd_Plrd_CN',
		'hmt'	=> 'hmt_Latn_ZZ',
		'hnd'	=> 'hnd_Arab_PK',
		'hne'	=> 'hne_Deva_IN',
		'hnj'	=> 'hnj_Hmng_LA',
		'hnn'	=> 'hnn_Latn_PH',
		'hno'	=> 'hno_Arab_PK',
		'ho'	=> 'ho_Latn_PG',
		'hoc'	=> 'hoc_Deva_IN',
		'hoj'	=> 'hoj_Deva_IN',
		'hot'	=> 'hot_Latn_ZZ',
		'hr'	=> 'hr_Latn_HR',
		'hsb'	=> 'hsb_Latn_DE',
		'hsn'	=> 'hsn_Hans_CN',
		'ht'	=> 'ht_Latn_HT',
		'hu'	=> 'hu_Latn_HU',
		'hui'	=> 'hui_Latn_ZZ',
		'hy'	=> 'hy_Armn_AM',
		'hz'	=> 'hz_Latn_NA',
		'ia'	=> 'ia_Latn_FR',
		'ian'	=> 'ian_Latn_ZZ',
		'iar'	=> 'iar_Latn_ZZ',
		'iba'	=> 'iba_Latn_MY',
		'ibb'	=> 'ibb_Latn_NG',
		'iby'	=> 'iby_Latn_ZZ',
		'ica'	=> 'ica_Latn_ZZ',
		'ich'	=> 'ich_Latn_ZZ',
		'id'	=> 'id_Latn_ID',
		'idd'	=> 'idd_Latn_ZZ',
		'idi'	=> 'idi_Latn_ZZ',
		'idu'	=> 'idu_Latn_ZZ',
		'ife'	=> 'ife_Latn_TG',
		'ig'	=> 'ig_Latn_NG',
		'igb'	=> 'igb_Latn_ZZ',
		'ige'	=> 'ige_Latn_ZZ',
		'ii'	=> 'ii_Yiii_CN',
		'ijj'	=> 'ijj_Latn_ZZ',
		'ik'	=> 'ik_Latn_US',
		'ikk'	=> 'ikk_Latn_ZZ',
		'ikt'	=> 'ikt_Latn_CA',
		'ikw'	=> 'ikw_Latn_ZZ',
		'ikx'	=> 'ikx_Latn_ZZ',
		'ilo'	=> 'ilo_Latn_PH',
		'imo'	=> 'imo_Latn_ZZ',
		'in'	=> 'in_Latn_ID',
		'inh'	=> 'inh_Cyrl_RU',
		'io'	=> 'io_Latn_001',
		'iou'	=> 'iou_Latn_ZZ',
		'iri'	=> 'iri_Latn_ZZ',
		'is'	=> 'is_Latn_IS',
		'it'	=> 'it_Latn_IT',
		'iu'	=> 'iu_Cans_CA',
		'iw'	=> 'iw_Hebr_IL',
		'iwm'	=> 'iwm_Latn_ZZ',
		'iws'	=> 'iws_Latn_ZZ',
		'izh'	=> 'izh_Latn_RU',
		'izi'	=> 'izi_Latn_ZZ',
		'ja'	=> 'ja_Jpan_JP',
		'jab'	=> 'jab_Latn_ZZ',
		'jam'	=> 'jam_Latn_JM',
		'jbo'	=> 'jbo_Latn_001',
		'jbu'	=> 'jbu_Latn_ZZ',
		'jen'	=> 'jen_Latn_ZZ',
		'jgk'	=> 'jgk_Latn_ZZ',
		'jgo'	=> 'jgo_Latn_CM',
		'ji'	=> 'ji_Hebr_UA',
		'jib'	=> 'jib_Latn_ZZ',
		'jmc'	=> 'jmc_Latn_TZ',
		'jml'	=> 'jml_Deva_NP',
		'jra'	=> 'jra_Latn_ZZ',
		'jut'	=> 'jut_Latn_DK',
		'jv'	=> 'jv_Latn_ID',
		'jw'	=> 'jw_Latn_ID',
		'ka'	=> 'ka_Geor_GE',
		'kaa'	=> 'kaa_Cyrl_UZ',
		'kab'	=> 'kab_Latn_DZ',
		'kac'	=> 'kac_Latn_MM',
		'kad'	=> 'kad_Latn_ZZ',
		'kai'	=> 'kai_Latn_ZZ',
		'kaj'	=> 'kaj_Latn_NG',
		'kam'	=> 'kam_Latn_KE',
		'kao'	=> 'kao_Latn_ML',
		'kbd'	=> 'kbd_Cyrl_RU',
		'kbm'	=> 'kbm_Latn_ZZ',
		'kbp'	=> 'kbp_Latn_ZZ',
		'kbq'	=> 'kbq_Latn_ZZ',
		'kbx'	=> 'kbx_Latn_ZZ',
		'kby'	=> 'kby_Arab_NE',
		'kcg'	=> 'kcg_Latn_NG',
		'kck'	=> 'kck_Latn_ZW',
		'kcl'	=> 'kcl_Latn_ZZ',
		'kct'	=> 'kct_Latn_ZZ',
		'kde'	=> 'kde_Latn_TZ',
		'kdh'	=> 'kdh_Arab_TG',
		'kdl'	=> 'kdl_Latn_ZZ',
		'kdt'	=> 'kdt_Thai_TH',
		'kea'	=> 'kea_Latn_CV',
		'ken'	=> 'ken_Latn_CM',
		'kez'	=> 'kez_Latn_ZZ',
		'kfo'	=> 'kfo_Latn_CI',
		'kfr'	=> 'kfr_Deva_IN',
		'kfy'	=> 'kfy_Deva_IN',
		'kg'	=> 'kg_Latn_CD',
		'kge'	=> 'kge_Latn_ID',
		'kgf'	=> 'kgf_Latn_ZZ',
		'kgp'	=> 'kgp_Latn_BR',
		'kha'	=> 'kha_Latn_IN',
		'khb'	=> 'khb_Talu_CN',
		'khn'	=> 'khn_Deva_IN',
		'khq'	=> 'khq_Latn_ML',
		'khs'	=> 'khs_Latn_ZZ',
		'kht'	=> 'kht_Mymr_IN',
		'khw'	=> 'khw_Arab_PK',
		'khz'	=> 'khz_Latn_ZZ',
		'ki'	=> 'ki_Latn_KE',
		'kij'	=> 'kij_Latn_ZZ',
		'kiu'	=> 'kiu_Latn_TR',
		'kiw'	=> 'kiw_Latn_ZZ',
		'kj'	=> 'kj_Latn_NA',
		'kjd'	=> 'kjd_Latn_ZZ',
		'kjg'	=> 'kjg_Laoo_LA',
		'kjs'	=> 'kjs_Latn_ZZ',
		'kjy'	=> 'kjy_Latn_ZZ',
		'kk'	=> 'kk_Cyrl_KZ',
		'kk_AF'	=> 'kk_Arab_AF',
		'kk_CN'	=> 'kk_Arab_CN',
		'kk_IR'	=> 'kk_Arab_IR',
		'kk_MN'	=> 'kk_Arab_MN',
		'kk_Arab'	=> 'kk_Arab_CN',
		'kkc'	=> 'kkc_Latn_ZZ',
		'kkj'	=> 'kkj_Latn_CM',
		'kl'	=> 'kl_Latn_GL',
		'kln'	=> 'kln_Latn_KE',
		'klq'	=> 'klq_Latn_ZZ',
		'klt'	=> 'klt_Latn_ZZ',
		'klx'	=> 'klx_Latn_ZZ',
		'km'	=> 'km_Khmr_KH',
		'kmb'	=> 'kmb_Latn_AO',
		'kmh'	=> 'kmh_Latn_ZZ',
		'kmo'	=> 'kmo_Latn_ZZ',
		'kms'	=> 'kms_Latn_ZZ',
		'kmu'	=> 'kmu_Latn_ZZ',
		'kmw'	=> 'kmw_Latn_ZZ',
		'kn'	=> 'kn_Knda_IN',
		'knf'	=> 'knf_Latn_GW',
		'knp'	=> 'knp_Latn_ZZ',
		'ko'	=> 'ko_Kore_KR',
		'koi'	=> 'koi_Cyrl_RU',
		'kok'	=> 'kok_Deva_IN',
		'kol'	=> 'kol_Latn_ZZ',
		'kos'	=> 'kos_Latn_FM',
		'koz'	=> 'koz_Latn_ZZ',
		'kpe'	=> 'kpe_Latn_LR',
		'kpf'	=> 'kpf_Latn_ZZ',
		'kpo'	=> 'kpo_Latn_ZZ',
		'kpr'	=> 'kpr_Latn_ZZ',
		'kpx'	=> 'kpx_Latn_ZZ',
		'kqb'	=> 'kqb_Latn_ZZ',
		'kqf'	=> 'kqf_Latn_ZZ',
		'kqs'	=> 'kqs_Latn_ZZ',
		'kqy'	=> 'kqy_Ethi_ZZ',
		'kr'	=> 'kr_Latn_ZZ',
		'krc'	=> 'krc_Cyrl_RU',
		'kri'	=> 'kri_Latn_SL',
		'krj'	=> 'krj_Latn_PH',
		'krl'	=> 'krl_Latn_RU',
		'krs'	=> 'krs_Latn_ZZ',
		'kru'	=> 'kru_Deva_IN',
		'ks'	=> 'ks_Arab_IN',
		'ksb'	=> 'ksb_Latn_TZ',
		'ksd'	=> 'ksd_Latn_ZZ',
		'ksf'	=> 'ksf_Latn_CM',
		'ksh'	=> 'ksh_Latn_DE',
		'ksj'	=> 'ksj_Latn_ZZ',
		'ksr'	=> 'ksr_Latn_ZZ',
		'ktb'	=> 'ktb_Ethi_ZZ',
		'ktm'	=> 'ktm_Latn_ZZ',
		'kto'	=> 'kto_Latn_ZZ',
		'ku'	=> 'ku_Latn_TR',
		'ku_LB'	=> 'ku_Arab_LB',
		'ku_Arab'	=> 'ku_Arab_IQ',
		'kub'	=> 'kub_Latn_ZZ',
		'kud'	=> 'kud_Latn_ZZ',
		'kue'	=> 'kue_Latn_ZZ',
		'kuj'	=> 'kuj_Latn_ZZ',
		'kum'	=> 'kum_Cyrl_RU',
		'kun'	=> 'kun_Latn_ZZ',
		'kup'	=> 'kup_Latn_ZZ',
		'kus'	=> 'kus_Latn_ZZ',
		'kv'	=> 'kv_Cyrl_RU',
		'kvg'	=> 'kvg_Latn_ZZ',
		'kvr'	=> 'kvr_Latn_ID',
		'kvx'	=> 'kvx_Arab_PK',
		'kw'	=> 'kw_Latn_GB',
		'kwj'	=> 'kwj_Latn_ZZ',
		'kwo'	=> 'kwo_Latn_ZZ',
		'kxa'	=> 'kxa_Latn_ZZ',
		'kxc'	=> 'kxc_Ethi_ZZ',
		'kxm'	=> 'kxm_Thai_TH',
		'kxp'	=> 'kxp_Arab_PK',
		'kxw'	=> 'kxw_Latn_ZZ',
		'kxz'	=> 'kxz_Latn_ZZ',
		'ky'	=> 'ky_Cyrl_KG',
		'ky_CN'	=> 'ky_Arab_CN',
		'ky_TR'	=> 'ky_Latn_TR',
		'ky_Arab'	=> 'ky_Arab_CN',
		'ky_Latn'	=> 'ky_Latn_TR',
		'kye'	=> 'kye_Latn_ZZ',
		'kyx'	=> 'kyx_Latn_ZZ',
		'kzr'	=> 'kzr_Latn_ZZ',
		'la'	=> 'la_Latn_VA',
		'lab'	=> 'lab_Lina_GR',
		'lad'	=> 'lad_Hebr_IL',
		'lag'	=> 'lag_Latn_TZ',
		'lah'	=> 'lah_Arab_PK',
		'laj'	=> 'laj_Latn_UG',
		'las'	=> 'las_Latn_ZZ',
		'lb'	=> 'lb_Latn_LU',
		'lbe'	=> 'lbe_Cyrl_RU',
		'lbu'	=> 'lbu_Latn_ZZ',
		'lbw'	=> 'lbw_Latn_ID',
		'lcm'	=> 'lcm_Latn_ZZ',
		'lcp'	=> 'lcp_Thai_CN',
		'ldb'	=> 'ldb_Latn_ZZ',
		'led'	=> 'led_Latn_ZZ',
		'lee'	=> 'lee_Latn_ZZ',
		'lem'	=> 'lem_Latn_ZZ',
		'lep'	=> 'lep_Lepc_IN',
		'leq'	=> 'leq_Latn_ZZ',
		'leu'	=> 'leu_Latn_ZZ',
		'lez'	=> 'lez_Cyrl_RU',
		'lg'	=> 'lg_Latn_UG',
		'lgg'	=> 'lgg_Latn_ZZ',
		'li'	=> 'li_Latn_NL',
		'lia'	=> 'lia_Latn_ZZ',
		'lid'	=> 'lid_Latn_ZZ',
		'lif'	=> 'lif_Deva_NP',
		'lif_Limb'	=> 'lif_Limb_IN',
		'lig'	=> 'lig_Latn_ZZ',
		'lih'	=> 'lih_Latn_ZZ',
		'lij'	=> 'lij_Latn_IT',
		'lis'	=> 'lis_Lisu_CN',
		'ljp'	=> 'ljp_Latn_ID',
		'lki'	=> 'lki_Arab_IR',
		'lkt'	=> 'lkt_Latn_US',
		'lle'	=> 'lle_Latn_ZZ',
		'lln'	=> 'lln_Latn_ZZ',
		'lmn'	=> 'lmn_Telu_IN',
		'lmo'	=> 'lmo_Latn_IT',
		'lmp'	=> 'lmp_Latn_ZZ',
		'ln'	=> 'ln_Latn_CD',
		'lns'	=> 'lns_Latn_ZZ',
		'lnu'	=> 'lnu_Latn_ZZ',
		'lo'	=> 'lo_Laoo_LA',
		'loj'	=> 'loj_Latn_ZZ',
		'lok'	=> 'lok_Latn_ZZ',
		'lol'	=> 'lol_Latn_CD',
		'lor'	=> 'lor_Latn_ZZ',
		'los'	=> 'los_Latn_ZZ',
		'loz'	=> 'loz_Latn_ZM',
		'lrc'	=> 'lrc_Arab_IR',
		'lt'	=> 'lt_Latn_LT',
		'ltg'	=> 'ltg_Latn_LV',
		'lu'	=> 'lu_Latn_CD',
		'lua'	=> 'lua_Latn_CD',
		'luo'	=> 'luo_Latn_KE',
		'luy'	=> 'luy_Latn_KE',
		'luz'	=> 'luz_Arab_IR',
		'lv'	=> 'lv_Latn_LV',
		'lwl'	=> 'lwl_Thai_TH',
		'lzh'	=> 'lzh_Hans_CN',
		'lzz'	=> 'lzz_Latn_TR',
		'mad'	=> 'mad_Latn_ID',
		'maf'	=> 'maf_Latn_CM',
		'mag'	=> 'mag_Deva_IN',
		'mai'	=> 'mai_Deva_IN',
		'mak'	=> 'mak_Latn_ID',
		'man'	=> 'man_Latn_GM',
		'man_GN'	=> 'man_Nkoo_GN',
		'man_Nkoo'	=> 'man_Nkoo_GN',
		'mas'	=> 'mas_Latn_KE',
		'maw'	=> 'maw_Latn_ZZ',
		'maz'	=> 'maz_Latn_MX',
		'mbh'	=> 'mbh_Latn_ZZ',
		'mbo'	=> 'mbo_Latn_ZZ',
		'mbq'	=> 'mbq_Latn_ZZ',
		'mbu'	=> 'mbu_Latn_ZZ',
		'mbw'	=> 'mbw_Latn_ZZ',
		'mci'	=> 'mci_Latn_ZZ',
		'mcp'	=> 'mcp_Latn_ZZ',
		'mcq'	=> 'mcq_Latn_ZZ',
		'mcr'	=> 'mcr_Latn_ZZ',
		'mcu'	=> 'mcu_Latn_ZZ',
		'mda'	=> 'mda_Latn_ZZ',
		'mde'	=> 'mde_Arab_ZZ',
		'mdf'	=> 'mdf_Cyrl_RU',
		'mdh'	=> 'mdh_Latn_PH',
		'mdj'	=> 'mdj_Latn_ZZ',
		'mdr'	=> 'mdr_Latn_ID',
		'mdx'	=> 'mdx_Ethi_ZZ',
		'med'	=> 'med_Latn_ZZ',
		'mee'	=> 'mee_Latn_ZZ',
		'mek'	=> 'mek_Latn_ZZ',
		'men'	=> 'men_Latn_SL',
		'mer'	=> 'mer_Latn_KE',
		'met'	=> 'met_Latn_ZZ',
		'meu'	=> 'meu_Latn_ZZ',
		'mfa'	=> 'mfa_Arab_TH',
		'mfe'	=> 'mfe_Latn_MU',
		'mfn'	=> 'mfn_Latn_ZZ',
		'mfo'	=> 'mfo_Latn_ZZ',
		'mfq'	=> 'mfq_Latn_ZZ',
		'mg'	=> 'mg_Latn_MG',
		'mgh'	=> 'mgh_Latn_MZ',
		'mgl'	=> 'mgl_Latn_ZZ',
		'mgo'	=> 'mgo_Latn_CM',
		'mgp'	=> 'mgp_Deva_NP',
		'mgy'	=> 'mgy_Latn_TZ',
		'mh'	=> 'mh_Latn_MH',
		'mhi'	=> 'mhi_Latn_ZZ',
		'mhl'	=> 'mhl_Latn_ZZ',
		'mi'	=> 'mi_Latn_NZ',
		'mif'	=> 'mif_Latn_ZZ',
		'min'	=> 'min_Latn_ID',
		'mis'	=> 'mis_Hatr_IQ',
		'mis_Medf'	=> 'mis_Medf_NG',
		'miw'	=> 'miw_Latn_ZZ',
		'mk'	=> 'mk_Cyrl_MK',
		'mki'	=> 'mki_Arab_ZZ',
		'mkl'	=> 'mkl_Latn_ZZ',
		'mkp'	=> 'mkp_Latn_ZZ',
		'mkw'	=> 'mkw_Latn_ZZ',
		'ml'	=> 'ml_Mlym_IN',
		'mle'	=> 'mle_Latn_ZZ',
		'mlp'	=> 'mlp_Latn_ZZ',
		'mls'	=> 'mls_Latn_SD',
		'mmo'	=> 'mmo_Latn_ZZ',
		'mmu'	=> 'mmu_Latn_ZZ',
		'mmx'	=> 'mmx_Latn_ZZ',
		'mn'	=> 'mn_Cyrl_MN',
		'mn_CN'	=> 'mn_Mong_CN',
		'mn_Mong'	=> 'mn_Mong_CN',
		'mna'	=> 'mna_Latn_ZZ',
		'mnf'	=> 'mnf_Latn_ZZ',
		'mni'	=> 'mni_Beng_IN',
		'mnw'	=> 'mnw_Mymr_MM',
		'moa'	=> 'moa_Latn_ZZ',
		'moe'	=> 'moe_Latn_CA',
		'moh'	=> 'moh_Latn_CA',
		'mos'	=> 'mos_Latn_BF',
		'mox'	=> 'mox_Latn_ZZ',
		'mpp'	=> 'mpp_Latn_ZZ',
		'mps'	=> 'mps_Latn_ZZ',
		'mpt'	=> 'mpt_Latn_ZZ',
		'mpx'	=> 'mpx_Latn_ZZ',
		'mql'	=> 'mql_Latn_ZZ',
		'mr'	=> 'mr_Deva_IN',
		'mrd'	=> 'mrd_Deva_NP',
		'mrj'	=> 'mrj_Cyrl_RU',
		'mro'	=> 'mro_Mroo_BD',
		'ms'	=> 'ms_Latn_MY',
		'ms_CC'	=> 'ms_Arab_CC',
		'ms_ID'	=> 'ms_Arab_ID',
		'mt'	=> 'mt_Latn_MT',
		'mtc'	=> 'mtc_Latn_ZZ',
		'mtf'	=> 'mtf_Latn_ZZ',
		'mti'	=> 'mti_Latn_ZZ',
		'mtr'	=> 'mtr_Deva_IN',
		'mua'	=> 'mua_Latn_CM',
		'mur'	=> 'mur_Latn_ZZ',
		'mus'	=> 'mus_Latn_US',
		'mva'	=> 'mva_Latn_ZZ',
		'mvn'	=> 'mvn_Latn_ZZ',
		'mvy'	=> 'mvy_Arab_PK',
		'mwk'	=> 'mwk_Latn_ML',
		'mwr'	=> 'mwr_Deva_IN',
		'mwv'	=> 'mwv_Latn_ID',
		'mxc'	=> 'mxc_Latn_ZW',
		'mxm'	=> 'mxm_Latn_ZZ',
		'my'	=> 'my_Mymr_MM',
		'myk'	=> 'myk_Latn_ZZ',
		'mym'	=> 'mym_Ethi_ZZ',
		'myv'	=> 'myv_Cyrl_RU',
		'myw'	=> 'myw_Latn_ZZ',
		'myx'	=> 'myx_Latn_UG',
		'myz'	=> 'myz_Mand_IR',
		'mzk'	=> 'mzk_Latn_ZZ',
		'mzm'	=> 'mzm_Latn_ZZ',
		'mzn'	=> 'mzn_Arab_IR',
		'mzp'	=> 'mzp_Latn_ZZ',
		'mzw'	=> 'mzw_Latn_ZZ',
		'mzz'	=> 'mzz_Latn_ZZ',
		'na'	=> 'na_Latn_NR',
		'nac'	=> 'nac_Latn_ZZ',
		'naf'	=> 'naf_Latn_ZZ',
		'nak'	=> 'nak_Latn_ZZ',
		'nan'	=> 'nan_Hans_CN',
		'nap'	=> 'nap_Latn_IT',
		'naq'	=> 'naq_Latn_NA',
		'nas'	=> 'nas_Latn_ZZ',
		'nb'	=> 'nb_Latn_NO',
		'nca'	=> 'nca_Latn_ZZ',
		'nce'	=> 'nce_Latn_ZZ',
		'ncf'	=> 'ncf_Latn_ZZ',
		'nch'	=> 'nch_Latn_MX',
		'nco'	=> 'nco_Latn_ZZ',
		'ncu'	=> 'ncu_Latn_ZZ',
		'nd'	=> 'nd_Latn_ZW',
		'ndc'	=> 'ndc_Latn_MZ',
		'nds'	=> 'nds_Latn_DE',
		'ne'	=> 'ne_Deva_NP',
		'neb'	=> 'neb_Latn_ZZ',
		'new'	=> 'new_Deva_NP',
		'nex'	=> 'nex_Latn_ZZ',
		'nfr'	=> 'nfr_Latn_ZZ',
		'ng'	=> 'ng_Latn_NA',
		'nga'	=> 'nga_Latn_ZZ',
		'ngb'	=> 'ngb_Latn_ZZ',
		'ngl'	=> 'ngl_Latn_MZ',
		'nhb'	=> 'nhb_Latn_ZZ',
		'nhe'	=> 'nhe_Latn_MX',
		'nhw'	=> 'nhw_Latn_MX',
		'nif'	=> 'nif_Latn_ZZ',
		'nii'	=> 'nii_Latn_ZZ',
		'nij'	=> 'nij_Latn_ID',
		'nin'	=> 'nin_Latn_ZZ',
		'niu'	=> 'niu_Latn_NU',
		'niy'	=> 'niy_Latn_ZZ',
		'niz'	=> 'niz_Latn_ZZ',
		'njo'	=> 'njo_Latn_IN',
		'nkg'	=> 'nkg_Latn_ZZ',
		'nko'	=> 'nko_Latn_ZZ',
		'nl'	=> 'nl_Latn_NL',
		'nmg'	=> 'nmg_Latn_CM',
		'nmz'	=> 'nmz_Latn_ZZ',
		'nn'	=> 'nn_Latn_NO',
		'nnf'	=> 'nnf_Latn_ZZ',
		'nnh'	=> 'nnh_Latn_CM',
		'nnk'	=> 'nnk_Latn_ZZ',
		'nnm'	=> 'nnm_Latn_ZZ',
		'no'	=> 'no_Latn_NO',
		'nod'	=> 'nod_Lana_TH',
		'noe'	=> 'noe_Deva_IN',
		'non'	=> 'non_Runr_SE',
		'nop'	=> 'nop_Latn_ZZ',
		'nou'	=> 'nou_Latn_ZZ',
		'nqo'	=> 'nqo_Nkoo_GN',
		'nr'	=> 'nr_Latn_ZA',
		'nrb'	=> 'nrb_Latn_ZZ',
		'nsk'	=> 'nsk_Cans_CA',
		'nsn'	=> 'nsn_Latn_ZZ',
		'nso'	=> 'nso_Latn_ZA',
		'nss'	=> 'nss_Latn_ZZ',
		'ntm'	=> 'ntm_Latn_ZZ',
		'ntr'	=> 'ntr_Latn_ZZ',
		'nui'	=> 'nui_Latn_ZZ',
		'nup'	=> 'nup_Latn_ZZ',
		'nus'	=> 'nus_Latn_SS',
		'nuv'	=> 'nuv_Latn_ZZ',
		'nux'	=> 'nux_Latn_ZZ',
		'nv'	=> 'nv_Latn_US',
		'nwb'	=> 'nwb_Latn_ZZ',
		'nxq'	=> 'nxq_Latn_CN',
		'nxr'	=> 'nxr_Latn_ZZ',
		'ny'	=> 'ny_Latn_MW',
		'nym'	=> 'nym_Latn_TZ',
		'nyn'	=> 'nyn_Latn_UG',
		'nzi'	=> 'nzi_Latn_GH',
		'oc'	=> 'oc_Latn_FR',
		'ogc'	=> 'ogc_Latn_ZZ',
		'okr'	=> 'okr_Latn_ZZ',
		'okv'	=> 'okv_Latn_ZZ',
		'om'	=> 'om_Latn_ET',
		'ong'	=> 'ong_Latn_ZZ',
		'onn'	=> 'onn_Latn_ZZ',
		'ons'	=> 'ons_Latn_ZZ',
		'opm'	=> 'opm_Latn_ZZ',
		'or'	=> 'or_Orya_IN',
		'oro'	=> 'oro_Latn_ZZ',
		'oru'	=> 'oru_Arab_ZZ',
		'os'	=> 'os_Cyrl_GE',
		'osa'	=> 'osa_Osge_US',
		'ota'	=> 'ota_Arab_ZZ',
		'otk'	=> 'otk_Orkh_MN',
		'ozm'	=> 'ozm_Latn_ZZ',
		'pa'	=> 'pa_Guru_IN',
		'pa_PK'	=> 'pa_Arab_PK',
		'pa_Arab'	=> 'pa_Arab_PK',
		'pag'	=> 'pag_Latn_PH',
		'pal'	=> 'pal_Phli_IR',
		'pal_Phlp'	=> 'pal_Phlp_CN',
		'pam'	=> 'pam_Latn_PH',
		'pap'	=> 'pap_Latn_AW',
		'pau'	=> 'pau_Latn_PW',
		'pbi'	=> 'pbi_Latn_ZZ',
		'pcd'	=> 'pcd_Latn_FR',
		'pcm'	=> 'pcm_Latn_NG',
		'pdc'	=> 'pdc_Latn_US',
		'pdt'	=> 'pdt_Latn_CA',
		'ped'	=> 'ped_Latn_ZZ',
		'peo'	=> 'peo_Xpeo_IR',
		'pex'	=> 'pex_Latn_ZZ',
		'pfl'	=> 'pfl_Latn_DE',
		'phl'	=> 'phl_Arab_ZZ',
		'phn'	=> 'phn_Phnx_LB',
		'pil'	=> 'pil_Latn_ZZ',
		'pip'	=> 'pip_Latn_ZZ',
		'pka'	=> 'pka_Brah_IN',
		'pko'	=> 'pko_Latn_KE',
		'pl'	=> 'pl_Latn_PL',
		'pla'	=> 'pla_Latn_ZZ',
		'pms'	=> 'pms_Latn_IT',
		'png'	=> 'png_Latn_ZZ',
		'pnn'	=> 'pnn_Latn_ZZ',
		'pnt'	=> 'pnt_Grek_GR',
		'pon'	=> 'pon_Latn_FM',
		'ppo'	=> 'ppo_Latn_ZZ',
		'pra'	=> 'pra_Khar_PK',
		'prd'	=> 'prd_Arab_IR',
		'prg'	=> 'prg_Latn_001',
		'ps'	=> 'ps_Arab_AF',
		'pss'	=> 'pss_Latn_ZZ',
		'pt'	=> 'pt_Latn_BR',
		'ptp'	=> 'ptp_Latn_ZZ',
		'puu'	=> 'puu_Latn_GA',
		'pwa'	=> 'pwa_Latn_ZZ',
		'qu'	=> 'qu_Latn_PE',
		'quc'	=> 'quc_Latn_GT',
		'qug'	=> 'qug_Latn_EC',
		'rai'	=> 'rai_Latn_ZZ',
		'raj'	=> 'raj_Deva_IN',
		'rao'	=> 'rao_Latn_ZZ',
		'rcf'	=> 'rcf_Latn_RE',
		'rej'	=> 'rej_Latn_ID',
		'rel'	=> 'rel_Latn_ZZ',
		'res'	=> 'res_Latn_ZZ',
		'rgn'	=> 'rgn_Latn_IT',
		'rhg'	=> 'rhg_Arab_MM',
		'ria'	=> 'ria_Latn_IN',
		'rif'	=> 'rif_Tfng_MA',
		'rif_NL'	=> 'rif_Latn_NL',
		'rjs'	=> 'rjs_Deva_NP',
		'rkt'	=> 'rkt_Beng_BD',
		'rm'	=> 'rm_Latn_CH',
		'rmf'	=> 'rmf_Latn_FI',
		'rmo'	=> 'rmo_Latn_CH',
		'rmt'	=> 'rmt_Arab_IR',
		'rmu'	=> 'rmu_Latn_SE',
		'rn'	=> 'rn_Latn_BI',
		'rna'	=> 'rna_Latn_ZZ',
		'rng'	=> 'rng_Latn_MZ',
		'ro'	=> 'ro_Latn_RO',
		'rob'	=> 'rob_Latn_ID',
		'rof'	=> 'rof_Latn_TZ',
		'roo'	=> 'roo_Latn_ZZ',
		'rro'	=> 'rro_Latn_ZZ',
		'rtm'	=> 'rtm_Latn_FJ',
		'ru'	=> 'ru_Cyrl_RU',
		'rue'	=> 'rue_Cyrl_UA',
		'rug'	=> 'rug_Latn_SB',
		'rw'	=> 'rw_Latn_RW',
		'rwk'	=> 'rwk_Latn_TZ',
		'rwo'	=> 'rwo_Latn_ZZ',
		'ryu'	=> 'ryu_Kana_JP',
		'sa'	=> 'sa_Deva_IN',
		'saf'	=> 'saf_Latn_GH',
		'sah'	=> 'sah_Cyrl_RU',
		'saq'	=> 'saq_Latn_KE',
		'sas'	=> 'sas_Latn_ID',
		'sat'	=> 'sat_Latn_IN',
		'sav'	=> 'sav_Latn_SN',
		'saz'	=> 'saz_Saur_IN',
		'sba'	=> 'sba_Latn_ZZ',
		'sbe'	=> 'sbe_Latn_ZZ',
		'sbp'	=> 'sbp_Latn_TZ',
		'sc'	=> 'sc_Latn_IT',
		'sck'	=> 'sck_Deva_IN',
		'scl'	=> 'scl_Arab_ZZ',
		'scn'	=> 'scn_Latn_IT',
		'sco'	=> 'sco_Latn_GB',
		'scs'	=> 'scs_Latn_CA',
		'sd'	=> 'sd_Arab_PK',
		'sd_Deva'	=> 'sd_Deva_IN',
		'sd_Khoj'	=> 'sd_Khoj_IN',
		'sd_Sind'	=> 'sd_Sind_IN',
		'sdc'	=> 'sdc_Latn_IT',
		'sdh'	=> 'sdh_Arab_IR',
		'se'	=> 'se_Latn_NO',
		'sef'	=> 'sef_Latn_CI',
		'seh'	=> 'seh_Latn_MZ',
		'sei'	=> 'sei_Latn_MX',
		'ses'	=> 'ses_Latn_ML',
		'sg'	=> 'sg_Latn_CF',
		'sga'	=> 'sga_Ogam_IE',
		'sgs'	=> 'sgs_Latn_LT',
		'sgw'	=> 'sgw_Ethi_ZZ',
		'sgz'	=> 'sgz_Latn_ZZ',
		'shi'	=> 'shi_Tfng_MA',
		'shk'	=> 'shk_Latn_ZZ',
		'shn'	=> 'shn_Mymr_MM',
		'shu'	=> 'shu_Arab_ZZ',
		'si'	=> 'si_Sinh_LK',
		'sid'	=> 'sid_Latn_ET',
		'sig'	=> 'sig_Latn_ZZ',
		'sil'	=> 'sil_Latn_ZZ',
		'sim'	=> 'sim_Latn_ZZ',
		'sjr'	=> 'sjr_Latn_ZZ',
		'sk'	=> 'sk_Latn_SK',
		'skc'	=> 'skc_Latn_ZZ',
		'skr'	=> 'skr_Arab_PK',
		'sks'	=> 'sks_Latn_ZZ',
		'sl'	=> 'sl_Latn_SI',
		'sld'	=> 'sld_Latn_ZZ',
		'sli'	=> 'sli_Latn_PL',
		'sll'	=> 'sll_Latn_ZZ',
		'sly'	=> 'sly_Latn_ID',
		'sm'	=> 'sm_Latn_WS',
		'sma'	=> 'sma_Latn_SE',
		'smj'	=> 'smj_Latn_SE',
		'smn'	=> 'smn_Latn_FI',
		'smp'	=> 'smp_Samr_IL',
		'smq'	=> 'smq_Latn_ZZ',
		'sms'	=> 'sms_Latn_FI',
		'sn'	=> 'sn_Latn_ZW',
		'snc'	=> 'snc_Latn_ZZ',
		'snk'	=> 'snk_Latn_ML',
		'snp'	=> 'snp_Latn_ZZ',
		'snx'	=> 'snx_Latn_ZZ',
		'sny'	=> 'sny_Latn_ZZ',
		'so'	=> 'so_Latn_SO',
		'sog'	=> 'sog_Sogd_UZ',
		'sok'	=> 'sok_Latn_ZZ',
		'soq'	=> 'soq_Latn_ZZ',
		'sou'	=> 'sou_Thai_TH',
		'soy'	=> 'soy_Latn_ZZ',
		'spd'	=> 'spd_Latn_ZZ',
		'spl'	=> 'spl_Latn_ZZ',
		'sps'	=> 'sps_Latn_ZZ',
		'sq'	=> 'sq_Latn_AL',
		'sr'	=> 'sr_Cyrl_RS',
		'sr_ME'	=> 'sr_Latn_ME',
		'sr_RO'	=> 'sr_Latn_RO',
		'sr_RU'	=> 'sr_Latn_RU',
		'sr_TR'	=> 'sr_Latn_TR',
		'srb'	=> 'srb_Sora_IN',
		'srn'	=> 'srn_Latn_SR',
		'srr'	=> 'srr_Latn_SN',
		'srx'	=> 'srx_Deva_IN',
		'ss'	=> 'ss_Latn_ZA',
		'ssd'	=> 'ssd_Latn_ZZ',
		'ssg'	=> 'ssg_Latn_ZZ',
		'ssy'	=> 'ssy_Latn_ER',
		'st'	=> 'st_Latn_ZA',
		'stk'	=> 'stk_Latn_ZZ',
		'stq'	=> 'stq_Latn_DE',
		'su'	=> 'su_Latn_ID',
		'sua'	=> 'sua_Latn_ZZ',
		'sue'	=> 'sue_Latn_ZZ',
		'suk'	=> 'suk_Latn_TZ',
		'sur'	=> 'sur_Latn_ZZ',
		'sus'	=> 'sus_Latn_GN',
		'sv'	=> 'sv_Latn_SE',
		'sw'	=> 'sw_Latn_TZ',
		'swb'	=> 'swb_Arab_YT',
		'swc'	=> 'swc_Latn_CD',
		'swg'	=> 'swg_Latn_DE',
		'swp'	=> 'swp_Latn_ZZ',
		'swv'	=> 'swv_Deva_IN',
		'sxn'	=> 'sxn_Latn_ID',
		'sxw'	=> 'sxw_Latn_ZZ',
		'syl'	=> 'syl_Beng_BD',
		'syr'	=> 'syr_Syrc_IQ',
		'szl'	=> 'szl_Latn_PL',
		'ta'	=> 'ta_Taml_IN',
		'taj'	=> 'taj_Deva_NP',
		'tal'	=> 'tal_Latn_ZZ',
		'tan'	=> 'tan_Latn_ZZ',
		'taq'	=> 'taq_Latn_ZZ',
		'tbc'	=> 'tbc_Latn_ZZ',
		'tbd'	=> 'tbd_Latn_ZZ',
		'tbf'	=> 'tbf_Latn_ZZ',
		'tbg'	=> 'tbg_Latn_ZZ',
		'tbo'	=> 'tbo_Latn_ZZ',
		'tbw'	=> 'tbw_Latn_PH',
		'tbz'	=> 'tbz_Latn_ZZ',
		'tci'	=> 'tci_Latn_ZZ',
		'tcy'	=> 'tcy_Knda_IN',
		'tdd'	=> 'tdd_Tale_CN',
		'tdg'	=> 'tdg_Deva_NP',
		'tdh'	=> 'tdh_Deva_NP',
		'te'	=> 'te_Telu_IN',
		'ted'	=> 'ted_Latn_ZZ',
		'tem'	=> 'tem_Latn_SL',
		'teo'	=> 'teo_Latn_UG',
		'tet'	=> 'tet_Latn_TL',
		'tfi'	=> 'tfi_Latn_ZZ',
		'tg'	=> 'tg_Cyrl_TJ',
		'tg_PK'	=> 'tg_Arab_PK',
		'tg_Arab'	=> 'tg_Arab_PK',
		'tgc'	=> 'tgc_Latn_ZZ',
		'tgo'	=> 'tgo_Latn_ZZ',
		'tgu'	=> 'tgu_Latn_ZZ',
		'th'	=> 'th_Thai_TH',
		'thl'	=> 'thl_Deva_NP',
		'thq'	=> 'thq_Deva_NP',
		'thr'	=> 'thr_Deva_NP',
		'ti'	=> 'ti_Ethi_ET',
		'tif'	=> 'tif_Latn_ZZ',
		'tig'	=> 'tig_Ethi_ER',
		'tik'	=> 'tik_Latn_ZZ',
		'tim'	=> 'tim_Latn_ZZ',
		'tio'	=> 'tio_Latn_ZZ',
		'tiv'	=> 'tiv_Latn_NG',
		'tk'	=> 'tk_Latn_TM',
		'tkl'	=> 'tkl_Latn_TK',
		'tkr'	=> 'tkr_Latn_AZ',
		'tkt'	=> 'tkt_Deva_NP',
		'tl'	=> 'tl_Latn_PH',
		'tlf'	=> 'tlf_Latn_ZZ',
		'tlx'	=> 'tlx_Latn_ZZ',
		'tly'	=> 'tly_Latn_AZ',
		'tmh'	=> 'tmh_Latn_NE',
		'tmy'	=> 'tmy_Latn_ZZ',
		'tn'	=> 'tn_Latn_ZA',
		'tnh'	=> 'tnh_Latn_ZZ',
		'to'	=> 'to_Latn_TO',
		'tof'	=> 'tof_Latn_ZZ',
		'tog'	=> 'tog_Latn_MW',
		'toq'	=> 'toq_Latn_ZZ',
		'tpi'	=> 'tpi_Latn_PG',
		'tpm'	=> 'tpm_Latn_ZZ',
		'tpz'	=> 'tpz_Latn_ZZ',
		'tqo'	=> 'tqo_Latn_ZZ',
		'tr'	=> 'tr_Latn_TR',
		'tru'	=> 'tru_Latn_TR',
		'trv'	=> 'trv_Latn_TW',
		'trw'	=> 'trw_Arab_ZZ',
		'ts'	=> 'ts_Latn_ZA',
		'tsd'	=> 'tsd_Grek_GR',
		'tsf'	=> 'tsf_Deva_NP',
		'tsg'	=> 'tsg_Latn_PH',
		'tsj'	=> 'tsj_Tibt_BT',
		'tsw'	=> 'tsw_Latn_ZZ',
		'tt'	=> 'tt_Cyrl_RU',
		'ttd'	=> 'ttd_Latn_ZZ',
		'tte'	=> 'tte_Latn_ZZ',
		'ttj'	=> 'ttj_Latn_UG',
		'ttr'	=> 'ttr_Latn_ZZ',
		'tts'	=> 'tts_Thai_TH',
		'ttt'	=> 'ttt_Latn_AZ',
		'tuh'	=> 'tuh_Latn_ZZ',
		'tul'	=> 'tul_Latn_ZZ',
		'tum'	=> 'tum_Latn_MW',
		'tuq'	=> 'tuq_Latn_ZZ',
		'tvd'	=> 'tvd_Latn_ZZ',
		'tvl'	=> 'tvl_Latn_TV',
		'tvu'	=> 'tvu_Latn_ZZ',
		'twh'	=> 'twh_Latn_ZZ',
		'twq'	=> 'twq_Latn_NE',
		'txg'	=> 'txg_Tang_CN',
		'ty'	=> 'ty_Latn_PF',
		'tya'	=> 'tya_Latn_ZZ',
		'tyv'	=> 'tyv_Cyrl_RU',
		'tzm'	=> 'tzm_Latn_MA',
		'ubu'	=> 'ubu_Latn_ZZ',
		'udm'	=> 'udm_Cyrl_RU',
		'ug'	=> 'ug_Arab_CN',
		'ug_KZ'	=> 'ug_Cyrl_KZ',
		'ug_MN'	=> 'ug_Cyrl_MN',
		'ug_Cyrl'	=> 'ug_Cyrl_KZ',
		'uga'	=> 'uga_Ugar_SY',
		'uk'	=> 'uk_Cyrl_UA',
		'uli'	=> 'uli_Latn_FM',
		'umb'	=> 'umb_Latn_AO',
		'unr'	=> 'unr_Beng_IN',
		'unr_NP'	=> 'unr_Deva_NP',
		'unr_Deva'	=> 'unr_Deva_NP',
		'unx'	=> 'unx_Beng_IN',
		'ur'	=> 'ur_Arab_PK',
		'uri'	=> 'uri_Latn_ZZ',
		'urt'	=> 'urt_Latn_ZZ',
		'urw'	=> 'urw_Latn_ZZ',
		'usa'	=> 'usa_Latn_ZZ',
		'utr'	=> 'utr_Latn_ZZ',
		'uvh'	=> 'uvh_Latn_ZZ',
		'uvl'	=> 'uvl_Latn_ZZ',
		'uz'	=> 'uz_Latn_UZ',
		'uz_AF'	=> 'uz_Arab_AF',
		'uz_CN'	=> 'uz_Cyrl_CN',
		'uz_Arab'	=> 'uz_Arab_AF',
		'vag'	=> 'vag_Latn_ZZ',
		'vai'	=> 'vai_Vaii_LR',
		'van'	=> 'van_Latn_ZZ',
		've'	=> 've_Latn_ZA',
		'vec'	=> 'vec_Latn_IT',
		'vep'	=> 'vep_Latn_RU',
		'vi'	=> 'vi_Latn_VN',
		'vic'	=> 'vic_Latn_SX',
		'viv'	=> 'viv_Latn_ZZ',
		'vls'	=> 'vls_Latn_BE',
		'vmf'	=> 'vmf_Latn_DE',
		'vmw'	=> 'vmw_Latn_MZ',
		'vo'	=> 'vo_Latn_001',
		'vot'	=> 'vot_Latn_RU',
		'vro'	=> 'vro_Latn_EE',
		'vun'	=> 'vun_Latn_TZ',
		'vut'	=> 'vut_Latn_ZZ',
		'wa'	=> 'wa_Latn_BE',
		'wae'	=> 'wae_Latn_CH',
		'waj'	=> 'waj_Latn_ZZ',
		'wal'	=> 'wal_Ethi_ET',
		'wan'	=> 'wan_Latn_ZZ',
		'war'	=> 'war_Latn_PH',
		'wbp'	=> 'wbp_Latn_AU',
		'wbq'	=> 'wbq_Telu_IN',
		'wbr'	=> 'wbr_Deva_IN',
		'wci'	=> 'wci_Latn_ZZ',
		'wer'	=> 'wer_Latn_ZZ',
		'wgi'	=> 'wgi_Latn_ZZ',
		'whg'	=> 'whg_Latn_ZZ',
		'wib'	=> 'wib_Latn_ZZ',
		'wiu'	=> 'wiu_Latn_ZZ',
		'wiv'	=> 'wiv_Latn_ZZ',
		'wja'	=> 'wja_Latn_ZZ',
		'wji'	=> 'wji_Latn_ZZ',
		'wls'	=> 'wls_Latn_WF',
		'wmo'	=> 'wmo_Latn_ZZ',
		'wnc'	=> 'wnc_Latn_ZZ',
		'wni'	=> 'wni_Arab_KM',
		'wnu'	=> 'wnu_Latn_ZZ',
		'wo'	=> 'wo_Latn_SN',
		'wob'	=> 'wob_Latn_ZZ',
		'wos'	=> 'wos_Latn_ZZ',
		'wrs'	=> 'wrs_Latn_ZZ',
		'wsg'	=> 'wsg_Gong_IN',
		'wsk'	=> 'wsk_Latn_ZZ',
		'wtm'	=> 'wtm_Deva_IN',
		'wuu'	=> 'wuu_Hans_CN',
		'wuv'	=> 'wuv_Latn_ZZ',
		'wwa'	=> 'wwa_Latn_ZZ',
		'xav'	=> 'xav_Latn_BR',
		'xbi'	=> 'xbi_Latn_ZZ',
		'xcr'	=> 'xcr_Cari_TR',
		'xes'	=> 'xes_Latn_ZZ',
		'xh'	=> 'xh_Latn_ZA',
		'xla'	=> 'xla_Latn_ZZ',
		'xlc'	=> 'xlc_Lyci_TR',
		'xld'	=> 'xld_Lydi_TR',
		'xmf'	=> 'xmf_Geor_GE',
		'xmn'	=> 'xmn_Mani_CN',
		'xmr'	=> 'xmr_Merc_SD',
		'xna'	=> 'xna_Narb_SA',
		'xnr'	=> 'xnr_Deva_IN',
		'xog'	=> 'xog_Latn_UG',
		'xon'	=> 'xon_Latn_ZZ',
		'xpr'	=> 'xpr_Prti_IR',
		'xrb'	=> 'xrb_Latn_ZZ',
		'xsa'	=> 'xsa_Sarb_YE',
		'xsi'	=> 'xsi_Latn_ZZ',
		'xsm'	=> 'xsm_Latn_ZZ',
		'xsr'	=> 'xsr_Deva_NP',
		'xwe'	=> 'xwe_Latn_ZZ',
		'yam'	=> 'yam_Latn_ZZ',
		'yao'	=> 'yao_Latn_MZ',
		'yap'	=> 'yap_Latn_FM',
		'yas'	=> 'yas_Latn_ZZ',
		'yat'	=> 'yat_Latn_ZZ',
		'yav'	=> 'yav_Latn_CM',
		'yay'	=> 'yay_Latn_ZZ',
		'yaz'	=> 'yaz_Latn_ZZ',
		'yba'	=> 'yba_Latn_ZZ',
		'ybb'	=> 'ybb_Latn_CM',
		'yby'	=> 'yby_Latn_ZZ',
		'yer'	=> 'yer_Latn_ZZ',
		'ygr'	=> 'ygr_Latn_ZZ',
		'ygw'	=> 'ygw_Latn_ZZ',
		'yi'	=> 'yi_Hebr_001',
		'yko'	=> 'yko_Latn_ZZ',
		'yle'	=> 'yle_Latn_ZZ',
		'ylg'	=> 'ylg_Latn_ZZ',
		'yll'	=> 'yll_Latn_ZZ',
		'yml'	=> 'yml_Latn_ZZ',
		'yo'	=> 'yo_Latn_NG',
		'yon'	=> 'yon_Latn_ZZ',
		'yrb'	=> 'yrb_Latn_ZZ',
		'yre'	=> 'yre_Latn_ZZ',
		'yrl'	=> 'yrl_Latn_BR',
		'yss'	=> 'yss_Latn_ZZ',
		'yua'	=> 'yua_Latn_MX',
		'yue'	=> 'yue_Hant_HK',
		'yue_CN'	=> 'yue_Hans_CN',
		'yue_Hans'	=> 'yue_Hans_CN',
		'yuj'	=> 'yuj_Latn_ZZ',
		'yut'	=> 'yut_Latn_ZZ',
		'yuw'	=> 'yuw_Latn_ZZ',
		'za'	=> 'za_Latn_CN',
		'zag'	=> 'zag_Latn_SD',
		'zdj'	=> 'zdj_Arab_KM',
		'zea'	=> 'zea_Latn_NL',
		'zgh'	=> 'zgh_Tfng_MA',
		'zh'	=> 'zh_Hans_CN',
		'zh_AU'	=> 'zh_Hant_AU',
		'zh_BN'	=> 'zh_Hant_BN',
		'zh_GB'	=> 'zh_Hant_GB',
		'zh_GF'	=> 'zh_Hant_GF',
		'zh_HK'	=> 'zh_Hant_HK',
		'zh_ID'	=> 'zh_Hant_ID',
		'zh_MO'	=> 'zh_Hant_MO',
		'zh_MY'	=> 'zh_Hant_MY',
		'zh_PA'	=> 'zh_Hant_PA',
		'zh_PF'	=> 'zh_Hant_PF',
		'zh_PH'	=> 'zh_Hant_PH',
		'zh_SR'	=> 'zh_Hant_SR',
		'zh_TH'	=> 'zh_Hant_TH',
		'zh_TW'	=> 'zh_Hant_TW',
		'zh_US'	=> 'zh_Hant_US',
		'zh_VN'	=> 'zh_Hant_VN',
		'zh_Bopo'	=> 'zh_Bopo_TW',
		'zh_Hanb'	=> 'zh_Hanb_TW',
		'zh_Hant'	=> 'zh_Hant_TW',
		'zhx'	=> 'zhx_Nshu_CN',
		'zia'	=> 'zia_Latn_ZZ',
		'zlm'	=> 'zlm_Latn_TG',
		'zmi'	=> 'zmi_Latn_MY',
		'zne'	=> 'zne_Latn_ZZ',
		'zu'	=> 'zu_Latn_ZA',
		'zza'	=> 'zza_Latn_TR',
		'und'	=> 'en_Latn_US',
		'und_002'	=> 'en_Latn_NG',
		'und_003'	=> 'en_Latn_US',
		'und_005'	=> 'pt_Latn_BR',
		'und_009'	=> 'en_Latn_AU',
		'und_011'	=> 'en_Latn_NG',
		'und_013'	=> 'es_Latn_MX',
		'und_014'	=> 'sw_Latn_TZ',
		'und_015'	=> 'ar_Arab_EG',
		'und_017'	=> 'sw_Latn_CD',
		'und_018'	=> 'en_Latn_ZA',
		'und_019'	=> 'en_Latn_US',
		'und_021'	=> 'en_Latn_US',
		'und_029'	=> 'es_Latn_CU',
		'und_030'	=> 'zh_Hans_CN',
		'und_034'	=> 'hi_Deva_IN',
		'und_035'	=> 'id_Latn_ID',
		'und_039'	=> 'it_Latn_IT',
		'und_053'	=> 'en_Latn_AU',
		'und_054'	=> 'en_Latn_PG',
		'und_057'	=> 'en_Latn_GU',
		'und_061'	=> 'sm_Latn_WS',
		'und_142'	=> 'zh_Hans_CN',
		'und_143'	=> 'uz_Latn_UZ',
		'und_145'	=> 'ar_Arab_SA',
		'und_150'	=> 'ru_Cyrl_RU',
		'und_151'	=> 'ru_Cyrl_RU',
		'und_154'	=> 'en_Latn_GB',
		'und_155'	=> 'de_Latn_DE',
		'und_202'	=> 'en_Latn_NG',
		'und_419'	=> 'es_Latn_419',
		'und_AD'	=> 'ca_Latn_AD',
		'und_AE'	=> 'ar_Arab_AE',
		'und_AF'	=> 'fa_Arab_AF',
		'und_AL'	=> 'sq_Latn_AL',
		'und_AM'	=> 'hy_Armn_AM',
		'und_AO'	=> 'pt_Latn_AO',
		'und_AQ'	=> 'und_Latn_AQ',
		'und_AR'	=> 'es_Latn_AR',
		'und_AS'	=> 'sm_Latn_AS',
		'und_AT'	=> 'de_Latn_AT',
		'und_AW'	=> 'nl_Latn_AW',
		'und_AX'	=> 'sv_Latn_AX',
		'und_AZ'	=> 'az_Latn_AZ',
		'und_BA'	=> 'bs_Latn_BA',
		'und_BD'	=> 'bn_Beng_BD',
		'und_BE'	=> 'nl_Latn_BE',
		'und_BF'	=> 'fr_Latn_BF',
		'und_BG'	=> 'bg_Cyrl_BG',
		'und_BH'	=> 'ar_Arab_BH',
		'und_BI'	=> 'rn_Latn_BI',
		'und_BJ'	=> 'fr_Latn_BJ',
		'und_BL'	=> 'fr_Latn_BL',
		'und_BN'	=> 'ms_Latn_BN',
		'und_BO'	=> 'es_Latn_BO',
		'und_BQ'	=> 'pap_Latn_BQ',
		'und_BR'	=> 'pt_Latn_BR',
		'und_BT'	=> 'dz_Tibt_BT',
		'und_BV'	=> 'und_Latn_BV',
		'und_BY'	=> 'be_Cyrl_BY',
		'und_CD'	=> 'sw_Latn_CD',
		'und_CF'	=> 'fr_Latn_CF',
		'und_CG'	=> 'fr_Latn_CG',
		'und_CH'	=> 'de_Latn_CH',
		'und_CI'	=> 'fr_Latn_CI',
		'und_CL'	=> 'es_Latn_CL',
		'und_CM'	=> 'fr_Latn_CM',
		'und_CN'	=> 'zh_Hans_CN',
		'und_CO'	=> 'es_Latn_CO',
		'und_CP'	=> 'und_Latn_CP',
		'und_CR'	=> 'es_Latn_CR',
		'und_CU'	=> 'es_Latn_CU',
		'und_CV'	=> 'pt_Latn_CV',
		'und_CW'	=> 'pap_Latn_CW',
		'und_CY'	=> 'el_Grek_CY',
		'und_CZ'	=> 'cs_Latn_CZ',
		'und_DE'	=> 'de_Latn_DE',
		'und_DJ'	=> 'aa_Latn_DJ',
		'und_DK'	=> 'da_Latn_DK',
		'und_DO'	=> 'es_Latn_DO',
		'und_DZ'	=> 'ar_Arab_DZ',
		'und_EA'	=> 'es_Latn_EA',
		'und_EC'	=> 'es_Latn_EC',
		'und_EE'	=> 'et_Latn_EE',
		'und_EG'	=> 'ar_Arab_EG',
		'und_EH'	=> 'ar_Arab_EH',
		'und_ER'	=> 'ti_Ethi_ER',
		'und_ES'	=> 'es_Latn_ES',
		'und_ET'	=> 'am_Ethi_ET',
		'und_EU'	=> 'en_Latn_GB',
		'und_EZ'	=> 'de_Latn_EZ',
		'und_FI'	=> 'fi_Latn_FI',
		'und_FO'	=> 'fo_Latn_FO',
		'und_FR'	=> 'fr_Latn_FR',
		'und_GA'	=> 'fr_Latn_GA',
		'und_GE'	=> 'ka_Geor_GE',
		'und_GF'	=> 'fr_Latn_GF',
		'und_GH'	=> 'ak_Latn_GH',
		'und_GL'	=> 'kl_Latn_GL',
		'und_GN'	=> 'fr_Latn_GN',
		'und_GP'	=> 'fr_Latn_GP',
		'und_GQ'	=> 'es_Latn_GQ',
		'und_GR'	=> 'el_Grek_GR',
		'und_GS'	=> 'und_Latn_GS',
		'und_GT'	=> 'es_Latn_GT',
		'und_GW'	=> 'pt_Latn_GW',
		'und_HK'	=> 'zh_Hant_HK',
		'und_HM'	=> 'und_Latn_HM',
		'und_HN'	=> 'es_Latn_HN',
		'und_HR'	=> 'hr_Latn_HR',
		'und_HT'	=> 'ht_Latn_HT',
		'und_HU'	=> 'hu_Latn_HU',
		'und_IC'	=> 'es_Latn_IC',
		'und_ID'	=> 'id_Latn_ID',
		'und_IL'	=> 'he_Hebr_IL',
		'und_IN'	=> 'hi_Deva_IN',
		'und_IQ'	=> 'ar_Arab_IQ',
		'und_IR'	=> 'fa_Arab_IR',
		'und_IS'	=> 'is_Latn_IS',
		'und_IT'	=> 'it_Latn_IT',
		'und_JO'	=> 'ar_Arab_JO',
		'und_JP'	=> 'ja_Jpan_JP',
		'und_KE'	=> 'sw_Latn_KE',
		'und_KG'	=> 'ky_Cyrl_KG',
		'und_KH'	=> 'km_Khmr_KH',
		'und_KM'	=> 'ar_Arab_KM',
		'und_KP'	=> 'ko_Kore_KP',
		'und_KR'	=> 'ko_Kore_KR',
		'und_KW'	=> 'ar_Arab_KW',
		'und_KZ'	=> 'ru_Cyrl_KZ',
		'und_LA'	=> 'lo_Laoo_LA',
		'und_LB'	=> 'ar_Arab_LB',
		'und_LI'	=> 'de_Latn_LI',
		'und_LK'	=> 'si_Sinh_LK',
		'und_LS'	=> 'st_Latn_LS',
		'und_LT'	=> 'lt_Latn_LT',
		'und_LU'	=> 'fr_Latn_LU',
		'und_LV'	=> 'lv_Latn_LV',
		'und_LY'	=> 'ar_Arab_LY',
		'und_MA'	=> 'ar_Arab_MA',
		'und_MC'	=> 'fr_Latn_MC',
		'und_MD'	=> 'ro_Latn_MD',
		'und_ME'	=> 'sr_Latn_ME',
		'und_MF'	=> 'fr_Latn_MF',
		'und_MG'	=> 'mg_Latn_MG',
		'und_MK'	=> 'mk_Cyrl_MK',
		'und_ML'	=> 'bm_Latn_ML',
		'und_MM'	=> 'my_Mymr_MM',
		'und_MN'	=> 'mn_Cyrl_MN',
		'und_MO'	=> 'zh_Hant_MO',
		'und_MQ'	=> 'fr_Latn_MQ',
		'und_MR'	=> 'ar_Arab_MR',
		'und_MT'	=> 'mt_Latn_MT',
		'und_MU'	=> 'mfe_Latn_MU',
		'und_MV'	=> 'dv_Thaa_MV',
		'und_MX'	=> 'es_Latn_MX',
		'und_MY'	=> 'ms_Latn_MY',
		'und_MZ'	=> 'pt_Latn_MZ',
		'und_NA'	=> 'af_Latn_NA',
		'und_NC'	=> 'fr_Latn_NC',
		'und_NE'	=> 'ha_Latn_NE',
		'und_NI'	=> 'es_Latn_NI',
		'und_NL'	=> 'nl_Latn_NL',
		'und_NO'	=> 'nb_Latn_NO',
		'und_NP'	=> 'ne_Deva_NP',
		'und_OM'	=> 'ar_Arab_OM',
		'und_PA'	=> 'es_Latn_PA',
		'und_PE'	=> 'es_Latn_PE',
		'und_PF'	=> 'fr_Latn_PF',
		'und_PG'	=> 'tpi_Latn_PG',
		'und_PH'	=> 'fil_Latn_PH',
		'und_PK'	=> 'ur_Arab_PK',
		'und_PL'	=> 'pl_Latn_PL',
		'und_PM'	=> 'fr_Latn_PM',
		'und_PR'	=> 'es_Latn_PR',
		'und_PS'	=> 'ar_Arab_PS',
		'und_PT'	=> 'pt_Latn_PT',
		'und_PW'	=> 'pau_Latn_PW',
		'und_PY'	=> 'gn_Latn_PY',
		'und_QA'	=> 'ar_Arab_QA',
		'und_QO'	=> 'en_Latn_DG',
		'und_RE'	=> 'fr_Latn_RE',
		'und_RO'	=> 'ro_Latn_RO',
		'und_RS'	=> 'sr_Cyrl_RS',
		'und_RU'	=> 'ru_Cyrl_RU',
		'und_RW'	=> 'rw_Latn_RW',
		'und_SA'	=> 'ar_Arab_SA',
		'und_SC'	=> 'fr_Latn_SC',
		'und_SD'	=> 'ar_Arab_SD',
		'und_SE'	=> 'sv_Latn_SE',
		'und_SI'	=> 'sl_Latn_SI',
		'und_SJ'	=> 'nb_Latn_SJ',
		'und_SK'	=> 'sk_Latn_SK',
		'und_SM'	=> 'it_Latn_SM',
		'und_SN'	=> 'fr_Latn_SN',
		'und_SO'	=> 'so_Latn_SO',
		'und_SR'	=> 'nl_Latn_SR',
		'und_ST'	=> 'pt_Latn_ST',
		'und_SV'	=> 'es_Latn_SV',
		'und_SY'	=> 'ar_Arab_SY',
		'und_TD'	=> 'fr_Latn_TD',
		'und_TF'	=> 'fr_Latn_TF',
		'und_TG'	=> 'fr_Latn_TG',
		'und_TH'	=> 'th_Thai_TH',
		'und_TJ'	=> 'tg_Cyrl_TJ',
		'und_TK'	=> 'tkl_Latn_TK',
		'und_TL'	=> 'pt_Latn_TL',
		'und_TM'	=> 'tk_Latn_TM',
		'und_TN'	=> 'ar_Arab_TN',
		'und_TO'	=> 'to_Latn_TO',
		'und_TR'	=> 'tr_Latn_TR',
		'und_TV'	=> 'tvl_Latn_TV',
		'und_TW'	=> 'zh_Hant_TW',
		'und_TZ'	=> 'sw_Latn_TZ',
		'und_UA'	=> 'uk_Cyrl_UA',
		'und_UG'	=> 'sw_Latn_UG',
		'und_UY'	=> 'es_Latn_UY',
		'und_UZ'	=> 'uz_Latn_UZ',
		'und_VA'	=> 'it_Latn_VA',
		'und_VE'	=> 'es_Latn_VE',
		'und_VN'	=> 'vi_Latn_VN',
		'und_VU'	=> 'bi_Latn_VU',
		'und_WF'	=> 'fr_Latn_WF',
		'und_WS'	=> 'sm_Latn_WS',
		'und_XK'	=> 'sq_Latn_XK',
		'und_YE'	=> 'ar_Arab_YE',
		'und_YT'	=> 'fr_Latn_YT',
		'und_ZW'	=> 'sn_Latn_ZW',
		'und_Adlm'	=> 'ff_Adlm_GN',
		'und_Aghb'	=> 'lez_Aghb_RU',
		'und_Ahom'	=> 'aho_Ahom_IN',
		'und_Arab'	=> 'ar_Arab_EG',
		'und_Arab_CC'	=> 'ms_Arab_CC',
		'und_Arab_CN'	=> 'ug_Arab_CN',
		'und_Arab_GB'	=> 'ks_Arab_GB',
		'und_Arab_ID'	=> 'ms_Arab_ID',
		'und_Arab_IN'	=> 'ur_Arab_IN',
		'und_Arab_KH'	=> 'cja_Arab_KH',
		'und_Arab_MM'	=> 'rhg_Arab_MM',
		'und_Arab_MN'	=> 'kk_Arab_MN',
		'und_Arab_MU'	=> 'ur_Arab_MU',
		'und_Arab_NG'	=> 'ha_Arab_NG',
		'und_Arab_PK'	=> 'ur_Arab_PK',
		'und_Arab_TG'	=> 'apd_Arab_TG',
		'und_Arab_TH'	=> 'mfa_Arab_TH',
		'und_Arab_TJ'	=> 'fa_Arab_TJ',
		'und_Arab_TR'	=> 'az_Arab_TR',
		'und_Arab_YT'	=> 'swb_Arab_YT',
		'und_Armi'	=> 'arc_Armi_IR',
		'und_Armn'	=> 'hy_Armn_AM',
		'und_Avst'	=> 'ae_Avst_IR',
		'und_Bali'	=> 'ban_Bali_ID',
		'und_Bamu'	=> 'bax_Bamu_CM',
		'und_Bass'	=> 'bsq_Bass_LR',
		'und_Batk'	=> 'bbc_Batk_ID',
		'und_Beng'	=> 'bn_Beng_BD',
		'und_Bhks'	=> 'sa_Bhks_IN',
		'und_Bopo'	=> 'zh_Bopo_TW',
		'und_Brah'	=> 'pka_Brah_IN',
		'und_Brai'	=> 'fr_Brai_FR',
		'und_Bugi'	=> 'bug_Bugi_ID',
		'und_Buhd'	=> 'bku_Buhd_PH',
		'und_Cakm'	=> 'ccp_Cakm_BD',
		'und_Cans'	=> 'cr_Cans_CA',
		'und_Cari'	=> 'xcr_Cari_TR',
		'und_Cham'	=> 'cjm_Cham_VN',
		'und_Cher'	=> 'chr_Cher_US',
		'und_Copt'	=> 'cop_Copt_EG',
		'und_Cprt'	=> 'grc_Cprt_CY',
		'und_Cyrl'	=> 'ru_Cyrl_RU',
		'und_Cyrl_AL'	=> 'mk_Cyrl_AL',
		'und_Cyrl_BA'	=> 'sr_Cyrl_BA',
		'und_Cyrl_GE'	=> 'ab_Cyrl_GE',
		'und_Cyrl_GR'	=> 'mk_Cyrl_GR',
		'und_Cyrl_MD'	=> 'uk_Cyrl_MD',
		'und_Cyrl_RO'	=> 'bg_Cyrl_RO',
		'und_Cyrl_SK'	=> 'uk_Cyrl_SK',
		'und_Cyrl_TR'	=> 'kbd_Cyrl_TR',
		'und_Cyrl_XK'	=> 'sr_Cyrl_XK',
		'und_Deva'	=> 'hi_Deva_IN',
		'und_Deva_BT'	=> 'ne_Deva_BT',
		'und_Deva_FJ'	=> 'hif_Deva_FJ',
		'und_Deva_MU'	=> 'bho_Deva_MU',
		'und_Deva_PK'	=> 'btv_Deva_PK',
		'und_Dogr'	=> 'doi_Dogr_IN',
		'und_Dupl'	=> 'fr_Dupl_FR',
		'und_Egyp'	=> 'egy_Egyp_EG',
		'und_Elba'	=> 'sq_Elba_AL',
		'und_Ethi'	=> 'am_Ethi_ET',
		'und_Geor'	=> 'ka_Geor_GE',
		'und_Glag'	=> 'cu_Glag_BG',
		'und_Gong'	=> 'wsg_Gong_IN',
		'und_Gonm'	=> 'esg_Gonm_IN',
		'und_Goth'	=> 'got_Goth_UA',
		'und_Gran'	=> 'sa_Gran_IN',
		'und_Grek'	=> 'el_Grek_GR',
		'und_Grek_TR'	=> 'bgx_Grek_TR',
		'und_Gujr'	=> 'gu_Gujr_IN',
		'und_Guru'	=> 'pa_Guru_IN',
		'und_Hanb'	=> 'zh_Hanb_TW',
		'und_Hang'	=> 'ko_Hang_KR',
		'und_Hani'	=> 'zh_Hani_CN',
		'und_Hano'	=> 'hnn_Hano_PH',
		'und_Hans'	=> 'zh_Hans_CN',
		'und_Hant'	=> 'zh_Hant_TW',
		'und_Hatr'	=> 'mis_Hatr_IQ',
		'und_Hebr'	=> 'he_Hebr_IL',
		'und_Hebr_CA'	=> 'yi_Hebr_CA',
		'und_Hebr_GB'	=> 'yi_Hebr_GB',
		'und_Hebr_SE'	=> 'yi_Hebr_SE',
		'und_Hebr_UA'	=> 'yi_Hebr_UA',
		'und_Hebr_US'	=> 'yi_Hebr_US',
		'und_Hira'	=> 'ja_Hira_JP',
		'und_Hluw'	=> 'hlu_Hluw_TR',
		'und_Hmng'	=> 'hnj_Hmng_LA',
		'und_Hung'	=> 'hu_Hung_HU',
		'und_Ital'	=> 'ett_Ital_IT',
		'und_Jamo'	=> 'ko_Jamo_KR',
		'und_Java'	=> 'jv_Java_ID',
		'und_Jpan'	=> 'ja_Jpan_JP',
		'und_Kali'	=> 'eky_Kali_MM',
		'und_Kana'	=> 'ja_Kana_JP',
		'und_Khar'	=> 'pra_Khar_PK',
		'und_Khmr'	=> 'km_Khmr_KH',
		'und_Khoj'	=> 'sd_Khoj_IN',
		'und_Knda'	=> 'kn_Knda_IN',
		'und_Kore'	=> 'ko_Kore_KR',
		'und_Kthi'	=> 'bho_Kthi_IN',
		'und_Lana'	=> 'nod_Lana_TH',
		'und_Laoo'	=> 'lo_Laoo_LA',
		'und_Latn_AF'	=> 'tk_Latn_AF',
		'und_Latn_AM'	=> 'ku_Latn_AM',
		'und_Latn_CN'	=> 'za_Latn_CN',
		'und_Latn_CY'	=> 'tr_Latn_CY',
		'und_Latn_DZ'	=> 'fr_Latn_DZ',
		'und_Latn_ET'	=> 'en_Latn_ET',
		'und_Latn_GE'	=> 'ku_Latn_GE',
		'und_Latn_IR'	=> 'tk_Latn_IR',
		'und_Latn_KM'	=> 'fr_Latn_KM',
		'und_Latn_MA'	=> 'fr_Latn_MA',
		'und_Latn_MK'	=> 'sq_Latn_MK',
		'und_Latn_MM'	=> 'kac_Latn_MM',
		'und_Latn_MO'	=> 'pt_Latn_MO',
		'und_Latn_MR'	=> 'fr_Latn_MR',
		'und_Latn_RU'	=> 'krl_Latn_RU',
		'und_Latn_SY'	=> 'fr_Latn_SY',
		'und_Latn_TN'	=> 'fr_Latn_TN',
		'und_Latn_TW'	=> 'trv_Latn_TW',
		'und_Latn_UA'	=> 'pl_Latn_UA',
		'und_Lepc'	=> 'lep_Lepc_IN',
		'und_Limb'	=> 'lif_Limb_IN',
		'und_Lina'	=> 'lab_Lina_GR',
		'und_Linb'	=> 'grc_Linb_GR',
		'und_Lisu'	=> 'lis_Lisu_CN',
		'und_Lyci'	=> 'xlc_Lyci_TR',
		'und_Lydi'	=> 'xld_Lydi_TR',
		'und_Mahj'	=> 'hi_Mahj_IN',
		'und_Maka'	=> 'mak_Maka_ID',
		'und_Mand'	=> 'myz_Mand_IR',
		'und_Mani'	=> 'xmn_Mani_CN',
		'und_Marc'	=> 'bo_Marc_CN',
		'und_Medf'	=> 'mis_Medf_NG',
		'und_Mend'	=> 'men_Mend_SL',
		'und_Merc'	=> 'xmr_Merc_SD',
		'und_Mero'	=> 'xmr_Mero_SD',
		'und_Mlym'	=> 'ml_Mlym_IN',
		'und_Modi'	=> 'mr_Modi_IN',
		'und_Mong'	=> 'mn_Mong_CN',
		'und_Mroo'	=> 'mro_Mroo_BD',
		'und_Mtei'	=> 'mni_Mtei_IN',
		'und_Mult'	=> 'skr_Mult_PK',
		'und_Mymr'	=> 'my_Mymr_MM',
		'und_Mymr_IN'	=> 'kht_Mymr_IN',
		'und_Mymr_TH'	=> 'mnw_Mymr_TH',
		'und_Narb'	=> 'xna_Narb_SA',
		'und_Nbat'	=> 'arc_Nbat_JO',
		'und_Newa'	=> 'new_Newa_NP',
		'und_Nkoo'	=> 'man_Nkoo_GN',
		'und_Nshu'	=> 'zhx_Nshu_CN',
		'und_Ogam'	=> 'sga_Ogam_IE',
		'und_Olck'	=> 'sat_Olck_IN',
		'und_Orkh'	=> 'otk_Orkh_MN',
		'und_Orya'	=> 'or_Orya_IN',
		'und_Osge'	=> 'osa_Osge_US',
		'und_Osma'	=> 'so_Osma_SO',
		'und_Palm'	=> 'arc_Palm_SY',
		'und_Pauc'	=> 'ctd_Pauc_MM',
		'und_Perm'	=> 'kv_Perm_RU',
		'und_Phag'	=> 'lzh_Phag_CN',
		'und_Phli'	=> 'pal_Phli_IR',
		'und_Phlp'	=> 'pal_Phlp_CN',
		'und_Phnx'	=> 'phn_Phnx_LB',
		'und_Plrd'	=> 'hmd_Plrd_CN',
		'und_Prti'	=> 'xpr_Prti_IR',
		'und_Rjng'	=> 'rej_Rjng_ID',
		'und_Rohg'	=> 'rhg_Rohg_MM',
		'und_Runr'	=> 'non_Runr_SE',
		'und_Samr'	=> 'smp_Samr_IL',
		'und_Sarb'	=> 'xsa_Sarb_YE',
		'und_Saur'	=> 'saz_Saur_IN',
		'und_Sgnw'	=> 'ase_Sgnw_US',
		'und_Shaw'	=> 'en_Shaw_GB',
		'und_Shrd'	=> 'sa_Shrd_IN',
		'und_Sidd'	=> 'sa_Sidd_IN',
		'und_Sind'	=> 'sd_Sind_IN',
		'und_Sinh'	=> 'si_Sinh_LK',
		'und_Sogd'	=> 'sog_Sogd_UZ',
		'und_Sogo'	=> 'sog_Sogo_UZ',
		'und_Sora'	=> 'srb_Sora_IN',
		'und_Soyo'	=> 'cmg_Soyo_MN',
		'und_Sund'	=> 'su_Sund_ID',
		'und_Sylo'	=> 'syl_Sylo_BD',
		'und_Syrc'	=> 'syr_Syrc_IQ',
		'und_Tagb'	=> 'tbw_Tagb_PH',
		'und_Takr'	=> 'doi_Takr_IN',
		'und_Tale'	=> 'tdd_Tale_CN',
		'und_Talu'	=> 'khb_Talu_CN',
		'und_Taml'	=> 'ta_Taml_IN',
		'und_Tang'	=> 'txg_Tang_CN',
		'und_Tavt'	=> 'blt_Tavt_VN',
		'und_Telu'	=> 'te_Telu_IN',
		'und_Tfng'	=> 'zgh_Tfng_MA',
		'und_Tglg'	=> 'fil_Tglg_PH',
		'und_Thaa'	=> 'dv_Thaa_MV',
		'und_Thai'	=> 'th_Thai_TH',
		'und_Thai_CN'	=> 'lcp_Thai_CN',
		'und_Thai_KH'	=> 'kdt_Thai_KH',
		'und_Thai_LA'	=> 'kdt_Thai_LA',
		'und_Tibt'	=> 'bo_Tibt_CN',
		'und_Tirh'	=> 'mai_Tirh_IN',
		'und_Ugar'	=> 'uga_Ugar_SY',
		'und_Vaii'	=> 'vai_Vaii_LR',
		'und_Wara'	=> 'hoc_Wara_IN',
		'und_Xpeo'	=> 'peo_Xpeo_IR',
		'und_Xsux'	=> 'akk_Xsux_IQ',
		'und_Yiii'	=> 'ii_Yiii_CN',
		'und_Zanb'	=> 'cmg_Zanb_MN',
	}},
);

no Moo::Role;

1;

# vim: tabstop=4
